@@ -30,6 +30,7 @@ import org.freeplane.features.icon.UIIcon;
 import org.freeplane.features.icon.factory.IconStoreFactory;
 import org.freeplane.features.map.EncryptionModel;
 import org.freeplane.features.map.MapController;
+import org.freeplane.features.map.MapWriter;
 import org.freeplane.features.map.NodeModel;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.ModeController;
@@ -42,21 +43,22 @@ public class EncryptionController implements IExtension {
 	private static final IconStore STORE = IconStoreFactory.ICON_STORE;
 	private static UIIcon decryptedIcon = STORE.getUIIcon("unlock.png");
 	private static UIIcon encryptedIcon = STORE.getUIIcon("lock.png");
-	
+
 	public static void install(EncryptionController encryptionController){
 		final ModeController modeController = Controller.getCurrentModeController();
 		modeController.addExtension(EncryptionController.class, encryptionController);
 		final EnterPassword pwdAction = new EnterPassword(encryptionController);
 		modeController.addAction(pwdAction);
 	}
-	
-	
+
+
 	public EncryptionController(final ModeController modeController) {
 		registerStateIconProvider(modeController);
     }
 
 	private void registerStateIconProvider(final ModeController modeController) {
 	    IconController.getController(modeController).addStateIconProvider(new IStateIconProvider() {
+			@Override
 			public UIIcon getStateIcon(NodeModel node) {
 				final EncryptionModel encryptionModel = EncryptionModel.getModel(node);
 				if (encryptionModel != null) {
@@ -75,38 +77,48 @@ public class EncryptionController implements IExtension {
 		});
     }
 
-	public void toggleCryptState(final NodeModel node, PasswordStrategy passwordStrategy) {
+	public void toggleLock(final NodeModel node, PasswordStrategy passwordStrategy) {
 		final EncryptionModel encryptionModel = EncryptionModel.getModel(node);
 		if (encryptionModel != null) {
 			final boolean wasFolded = node.isFolded();
 			final boolean wasAccessible = encryptionModel.isAccessible();
-			if (wasAccessible)
-				encryptionModel.calculateEncryptedContent(Controller.getCurrentModeController().getMapController());
-			else {
-				if (!doPasswordCheckAndDecryptNode(encryptionModel, passwordStrategy))
+			if (!wasAccessible && !doPasswordCheckAndDecryptNode(node, encryptionModel, passwordStrategy))
 					return;
-			}
 			final boolean becomesFolded = wasAccessible;
 			final boolean becomesAccessible = ! wasAccessible;
 			Controller.getCurrentController().getSelection().selectAsTheOnlyOneSelected(node);
+			final MapWriter mapWriter = Controller.getCurrentModeController().getMapController().getMapWriter();
 			final IActor actor = new IActor() {
+				@Override
 				public void act() {
-					encryptionModel.setAccessible(becomesAccessible);
+					if(becomesAccessible) {
+						encryptionModel.unlock();
+					}
+					else {
+						encryptionModel.lock(mapWriter);
+					}
 					if (becomesFolded != wasFolded) {
 						node.setFolded(becomesFolded);
 					}
-					fireEncyptionChangedEvent(node);
+					fireEncryptionChangedEvent(node);
 				}
 
+				@Override
 				public String getDescription() {
 					return "toggleCryptState";
 				}
 
+				@Override
 				public void undo() {
-					encryptionModel.setAccessible(wasAccessible);
+					if(wasAccessible) {
+						encryptionModel.unlock();
+					}
+					else {
+						encryptionModel.lock(mapWriter);
+					}
 					if(becomesFolded != wasFolded)
 						node.setFolded(wasFolded);
-					fireEncyptionChangedEvent(node);
+					fireEncryptionChangedEvent(node);
 				}
 			};
 			Controller.getCurrentModeController().execute(actor, node.getMap());
@@ -116,18 +128,16 @@ public class EncryptionController implements IExtension {
 		}
 	}
 
-	private boolean doPasswordCheckAndDecryptNode(final EncryptionModel encryptionModel, PasswordStrategy passwordStrategy) {
-		while (true) {
-			final StringBuilder password = passwordStrategy.getPassword();
-			if (passwordStrategy.isCancelled())
-			    return false;
-			if (!decrypt(encryptionModel, password)) {
-				passwordStrategy.onWrongPassword();
-				return false;
-			}
-			else {
-				return true;
-			}
+	private boolean doPasswordCheckAndDecryptNode(NodeModel node, final EncryptionModel encryptionModel, PasswordStrategy passwordStrategy) {
+		final StringBuilder password = passwordStrategy.getPassword(node);
+		if (passwordStrategy.isCancelled())
+			return false;
+		if (!decrypt(encryptionModel, password)) {
+			passwordStrategy.onWrongPassword();
+			return false;
+		}
+		else {
+			return true;
 		}
 	}
 
@@ -141,33 +151,35 @@ public class EncryptionController implements IExtension {
 			UITools.errorMessage(TextUtils.getText("can_not_encrypt_cloned_node"));
 			return;
 		}
-			
-		final StringBuilder password = passwordStrategy.getPasswordWithConfirmation();
+
+		final StringBuilder password = passwordStrategy.getPasswordWithConfirmation(node);
 		if (passwordStrategy.isCancelled()) {
 			return;
 		}
-		final EncryptionModel encryptionModel = new EncryptionModel(node);
-		encryptionModel.setEncrypter(new SingleDesEncrypter(password));
+		final EncryptionModel encryptionModel = new EncryptionModel(node, new SingleDesEncrypter(password));
 		final IActor actor = new IActor() {
+			@Override
 			public void act() {
 				node.addExtension(encryptionModel);
-				fireEncyptionChangedEvent(node);
+				fireEncryptionChangedEvent(node);
 			}
 
+			@Override
 			public String getDescription() {
 				return "encrypt";
 			}
 
+			@Override
 			public void undo() {
 				node.removeExtension(encryptionModel);
-				fireEncyptionChangedEvent(node);
+				fireEncryptionChangedEvent(node);
 			}
 		};
 		Controller.getCurrentModeController().execute(actor, node.getMap());
 	}
 
 
-	private void fireEncyptionChangedEvent(final NodeModel node) {
+	private void fireEncryptionChangedEvent(final NodeModel node) {
 		Controller.getCurrentModeController().getMapController().nodeRefresh(node, EncryptionModel.class, null, null);
 	}
 }
