@@ -1,11 +1,13 @@
 package org.freeplane.features.encrypt;
 
+import org.freeplane.features.map.NodeModel;
+
 /** not a clean strategy since it is allowed to be stateful. */
 public interface PasswordStrategy {
 
-    StringBuilder getPassword();
+    StringBuilder getPassword(NodeModel node);
     
-    StringBuilder getPasswordWithConfirmation();
+    StringBuilder getPasswordWithConfirmation(NodeModel node);
 
     void onWrongPassword();
 
