@@ -61,6 +61,7 @@ import org.freeplane.core.ui.components.FreeplaneToolBar;
 import org.freeplane.core.ui.components.JAutoToggleButton;
 import org.freeplane.core.ui.components.JComboBoxWithBorder;
 import org.freeplane.core.ui.components.UITools;
+import org.freeplane.core.ui.components.resizer.UIComponentVisibilityDispatcher;
 import org.freeplane.core.ui.menubuilders.generic.EntryVisitor;
 import org.freeplane.core.util.LogUtils;
 import org.freeplane.core.util.TextUtils;
@@ -82,7 +83,6 @@ import org.freeplane.features.map.NodeModel;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.ui.FrameController;
 import org.freeplane.features.ui.ToggleToolbarAction;
-import org.freeplane.features.ui.UIComponentVisibilityDispatcher;
 import org.freeplane.features.ui.ViewController;
 import org.freeplane.n3.nanoxml.IXMLParser;
 import org.freeplane.n3.nanoxml.IXMLReader;
@@ -94,6 +94,7 @@ import org.freeplane.n3.nanoxml.XMLWriter;
  * @author Dimitry Polivaev
  */
 public class FilterController implements IMapSelectionListener, IExtension {
+	public static final Color HIGHLIGHT_COLOR = Color.MAGENTA;
 	public static int TOOLBAR_SIDE = ViewController.TOP;
 	@SuppressWarnings("serial")
     @SelectableAction(checkOnPopup = true)
@@ -118,13 +119,16 @@ public class FilterController implements IMapSelectionListener, IExtension {
 
 	    private void changeFocusWhenVisibilityChanges(final JComponent toolBar) {
 	    	quickEditor.addAncestorListener(new AncestorListener() {
-	    		public void ancestorAdded(final AncestorEvent event) {
+	    		@Override
+				public void ancestorAdded(final AncestorEvent event) {
 	    			quickEditor.focusInputField(true);
 	    			quickEditor.removeAncestorListener(this);
 	    		}
-	    		public void ancestorMoved(final AncestorEvent event) {
+	    		@Override
+				public void ancestorMoved(final AncestorEvent event) {
 	    		}
-	    		public void ancestorRemoved(final AncestorEvent event) {
+	    		@Override
+				public void ancestorRemoved(final AncestorEvent event) {
 	    			final Component selectedComponent = Controller.getCurrentController().getMapViewManager().getSelectedComponent();
 	    			if(selectedComponent != null)
 	    				selectedComponent.requestFocusInWindow();
@@ -144,18 +148,22 @@ public class FilterController implements IMapSelectionListener, IExtension {
 		public FilterChangeListener() {
 		}
 
+		@Override
 		public void contentsChanged(final ListDataEvent e) {
 			if (e.getIndex0() == -1) {
 				applyFilter(false);
 			}
 		}
 
+		@Override
 		public void intervalAdded(final ListDataEvent e) {
 		}
 
+		@Override
 		public void intervalRemoved(final ListDataEvent e) {
 		}
 
+		@Override
 		public void stateChanged(final ChangeEvent e) {
 			applyFilter(false);
 		}
@@ -181,10 +189,10 @@ public class FilterController implements IMapSelectionListener, IExtension {
 			public boolean isNodeHighlighted(NodeModel node, boolean isPrinting) {
 				return !isPrinting && FilterController.getController(controller).isNodeHighlighted(node);
 			}
-			
+
 			@Override
 			public void configure(Graphics2D g, boolean isPrinting) {
-				g.setColor(Color.MAGENTA);
+				g.setColor(HIGHLIGHT_COLOR);
 			}
 		});
 
@@ -211,8 +219,10 @@ public class FilterController implements IMapSelectionListener, IExtension {
 	private ASelectableCondition highlightCondition;
 	private JComboBox activeFilterConditionComboBox;
 	private final FilterConditionEditor quickEditor;
+
 	static final int USER_DEFINED_CONDITION_START_INDEX = 3;
 	final private QuickFilterAction quickFilterAction;
+	private int mapChangeCounter;
 
 	public FilterController() {
 		Controller controller = Controller.getCurrentController();
@@ -242,6 +252,7 @@ public class FilterController implements IMapSelectionListener, IExtension {
 		quickEditor = new FilterConditionEditor(this, 0, true);
 		quickEditor.setEnterKeyActionListener( new ActionListener()  {
 
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				((QuickFindAction)Controller.getCurrentController().getAction("QuickFindAction.FORWARD")).executeAction(true);
 				if(getHighlightNodes().isSelected()){
@@ -294,17 +305,35 @@ public class FilterController implements IMapSelectionListener, IExtension {
 
 	/**
 	 */
+	@Override
 	public void afterMapChange(final MapModel oldMap, final MapModel newMap) {
 		if(filterToolbar == null){
 			return;
 		}
 		history.clear();
-		if (newMap != null) {
+		updateUILater();
+	}
+
+	private void updateUILater() {
+		mapChangeCounter++;
+		Controller.getCurrentController().getViewController().invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				mapChangeCounter--;
+				if (0 == mapChangeCounter)
+					updateUI();
+			}
+		});
+	}
+
+	private void updateUI() {
+		final MapModel map = Controller.getCurrentController().getMap();
+		if (map != null) {
 			filterToolbar.setEnabled(true);
 			activeFilterConditionComboBox.setEnabled(true);
 			quickEditor.setEnabled(true);
-			quickEditor.mapChanged(newMap);
-			final Filter filter = newMap.getFilter();
+			quickEditor.mapChanged(map);
+			final Filter filter = map.getFilter();
 			updateSettingsFromFilter(filter);
 			quickFilterAction.setSelected(isFilterActive());
 
@@ -346,9 +375,6 @@ public class FilterController implements IMapSelectionListener, IExtension {
 		}
 	}
 
-	public void beforeMapChange(final MapModel oldMap, final MapModel newMap) {
-	}
-
 	private Filter createFilter(final ASelectableCondition selectedCondition) {
 
 		final ASelectableCondition filterCondition;
@@ -372,7 +398,7 @@ public class FilterController implements IMapSelectionListener, IExtension {
 		    .getBooleanProperty("filter_toolbar_visible"));
 		Controller controller = Controller.getCurrentController();
 		FrameController frameController = (FrameController) controller.getViewController();
-		UIComponentVisibilityDispatcher.install(frameController, filterToolbar, "filter_toolbar_visible");
+		UIComponentVisibilityDispatcher.install(filterToolbar, "filter_toolbar_visible");
 		final JButton undoBtn = new JButton(controller.getAction("UndoFilterAction"));
 		final JButton redoBtn = new JButton(controller.getAction("RedoFilterAction"));
 		final JToggleButton showAncestorsBox = new JAutoToggleButton(controller.getAction("ShowAncestorsAction"),
@@ -457,6 +483,10 @@ public class FilterController implements IMapSelectionListener, IExtension {
 		return filterToolbar;
 	}
 
+	public FilterConditionEditor getQuickEditor() {
+		return quickEditor;
+	}
+
 	public FilterHistory getHistory() {
 		return history;
 	}
