@@ -42,6 +42,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.TreeSet;
+import java.util.WeakHashMap;
 
 import javax.swing.JOptionPane;
 
@@ -51,12 +52,12 @@ import org.freeplane.core.ui.AFreeplaneAction;
 import org.freeplane.core.ui.LengthUnits;
 import org.freeplane.core.ui.components.UITools;
 import org.freeplane.core.undo.IActor;
-import org.freeplane.core.util.Compat;
 import org.freeplane.core.util.ConfigurationUtils;
 import org.freeplane.core.util.LogUtils;
 import org.freeplane.core.util.Quantity;
 import org.freeplane.core.util.TextUtils;
-import org.freeplane.features.clipboard.ClipboardController;
+import org.freeplane.features.clipboard.ClipboardControllers;
+import org.freeplane.features.clipboard.mindmapmode.MClipboardControllers;
 import org.freeplane.features.icon.mindmapmode.MIconController.Keys;
 import org.freeplane.features.link.mindmapmode.MLinkController;
 import org.freeplane.features.map.AlwaysUnfoldedNode;
@@ -77,6 +78,8 @@ import org.freeplane.features.map.NodeMoveEvent;
 import org.freeplane.features.map.NodeRelativePath;
 import org.freeplane.features.map.SummaryLevels;
 import org.freeplane.features.map.SummaryNode;
+import org.freeplane.features.map.clipboard.MapClipboardController;
+import org.freeplane.features.map.mindmapmode.clipboard.MMapClipboardController;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.ModeController;
 import org.freeplane.features.mode.mindmapmode.MModeController;
@@ -94,8 +97,10 @@ import org.freeplane.features.url.NodeAndMapReference;
 import org.freeplane.features.url.UrlManager;
 import org.freeplane.features.url.mindmapmode.MFileManager;
 import org.freeplane.features.url.mindmapmode.MFileManager.AlternativeFileMode;
+import org.freeplane.features.url.mindmapmode.MapLoader;
 import org.freeplane.main.addons.AddOnsController;
 import org.freeplane.n3.nanoxml.XMLException;
+import org.freeplane.n3.nanoxml.XMLParseException;
 
 /**
  * @author Dimitry Polivaev
@@ -110,6 +115,7 @@ public class MMapController extends MapController {
 		super(modeController);
 		createActions(modeController);
 			addNodeSelectionListener(new INodeSelectionListener() {
+				@Override
 				public void onSelect(final NodeModel node) {
 					final ViewController viewController = Controller.getCurrentController().getViewController();
 					if (ResourceController.getResourceController().getBooleanProperty("display_node_id")) {
@@ -117,31 +123,32 @@ public class MMapController extends MapController {
 					}
 				}
 
+				@Override
 				public void onDeselect(final NodeModel node) {
 					final ViewController viewController = Controller.getCurrentController().getViewController();
 					viewController.addStatusInfo("display_node_id", null, null);
 				}
 			});
 			addMapChangeListener(new IMapChangeListener() {
-				
+
 				@Override
 				public void onPreNodeMoved(NodeMoveEvent nodeMoveEvent) {
 				}
-				
+
 				@Override
 				public void onPreNodeDelete(NodeDeletionEvent nodeDeletionEvent) {
 				}
-				
+
 				@Override
 				public void onNodeMoved(NodeMoveEvent nodeMoveEvent) {
 					if(! nodeMoveEvent.oldParent.equals(nodeMoveEvent.newParent))
 						onNodeDeleted(nodeMoveEvent.oldParent);
 				}
-				
+
 				@Override
 				public void onNodeInserted(NodeModel parent, NodeModel child, int newIndex) {
 				}
-				
+
 				@Override
 				public void onNodeDeleted(NodeDeletionEvent nodeDeletionEvent) {
 					final NodeModel parent = nodeDeletionEvent.parent;
@@ -153,12 +160,12 @@ public class MMapController extends MapController {
 						deleteSingleSummaryNode(node);
 					}
 				}
-				
+
 				@Override
 				public void mapChanged(MapChangeEvent event) {
 				}
 			});
-	
+
 	}
 
 	public NodeModel addNewNode(int newNodeMode) {
@@ -195,12 +202,18 @@ public class MMapController extends MapController {
 			}
 			//$FALL-THROUGH$
 			case MMapController.NEW_CHILD: {
-				final boolean parentFolded = isFolded(targetNode);
-				if (parentFolded) {
-					unfold(targetNode);
+				final boolean targetFolded = isFolded(targetNode);
+				IMapViewManager mapViewManager = getModeController().getController().getMapViewManager();
+				if (targetFolded) {
+					if(! targetNode.isRoot() && mapViewManager.hasHiddenChildren(targetNode.getParentNode())){
+						mapViewManager.hideChildren(targetNode);
+						targetNode.setFolded(false);
+					}
+					else
+						unfold(targetNode);
 				}
 				final int position = ResourceController.getResourceController().getProperty("placenewbranches").equals(
-				    "last") ? targetNode.getChildCount() : 0;
+				    "last") ? targetNode.getChildCount() - mapViewManager.getHiddenChildCount(targetNode) : 0;
 				newNode = addNewNode(targetNode, position, targetNode.isNewChildLeft());
 				if (newNode == null) {
 					return null;
@@ -215,14 +228,26 @@ public class MMapController extends MapController {
 		return newNode;
 	}
 
+
+
+	@Override
+	protected MapClipboardController createMapClipboardController() {
+		final MMapClipboardController mapClipboardController = new MMapClipboardController();
+		final MClipboardControllers extension = (MClipboardControllers) getModeController().getExtension(ClipboardControllers.class);
+		extension.add(mapClipboardController);
+		return mapClipboardController;
+	}
+
 	private void startEditingAfterSelect(final NodeModel newNode) {
 		final Component component = Controller.getCurrentController().getMapViewManager().getComponent(newNode);
 		if(component == null)
 			return;
 		component.addFocusListener(new FocusListener() {
+			@Override
 			public void focusLost(FocusEvent e) {
 			}
 
+			@Override
 			public void focusGained(FocusEvent e) {
 				e.getComponent().removeFocusListener(this);
 				final TextController textController = TextController.getController();
@@ -326,14 +351,17 @@ public class MMapController extends MapController {
 	    final MapModel map = parent.getMap();
 		newNode.setLeft(newNodeIsLeft);
 		final IActor actor = new IActor() {
+			@Override
 			public void act() {
 				insertNodeIntoWithoutUndo(newNode, parent, index);
 			}
 
+			@Override
 			public String getDescription() {
 				return "addNewNode";
 			}
 
+			@Override
 			public void undo() {
 				deleteWithoutUndo(parent, index);
 			}
@@ -342,7 +370,7 @@ public class MMapController extends MapController {
     }
 
 	public boolean close(final MapModel map) {
-		if (!map.isSaved()) {
+		if (!(map.isSaved() || map.isDocumentation())) {
 			Controller.getCurrentController().getMapViewManager().changeToMap(map);
 			final String text = TextUtils.getText("save_unsaved") + "\n" + map.getTitle();
 			final String title = TextUtils.getText("SaveAction.text");
@@ -369,7 +397,9 @@ public class MMapController extends MapController {
 		return true;
 	}
 
-	public void closeWithoutSaving(final MapModel map) {
+	@Override
+	synchronized public void closeWithoutSaving(final MapModel map) {
+		loadedMaps.remove(map);
 		super.closeWithoutSaving(map);
 	}
 
@@ -389,14 +419,14 @@ public class MMapController extends MapController {
 	public void deleteNode(NodeModel node) {
 		deleteNodes(Arrays.asList(node));
 	}
-	
+
 	public void deleteNodes(final List<NodeModel> nodes) {
 		final List<NodeModel> deletedNodesWithSummaryGroupIndicators = new SummaryGroupEdgeListAdder(nodes).addSummaryEdgeNodes();
 		for(NodeModel node : deletedNodesWithSummaryGroupIndicators){
 		    deleteSingleNodeWithClones(node);
 		}
 	}
-	
+
 	public void convertClonesToIndependentNodes(final NodeModel node){
 		final MLinkController linkController = (MLinkController) MLinkController.getController();
 		if(node.isCloneTreeRoot()){
@@ -408,27 +438,27 @@ public class MMapController extends MapController {
 
 	private void convertCloneToNode(final NodeModel node) {
 		final MModeController mModeController = getMModeController();
-		final ClipboardController clipboardController = mModeController.getExtension(ClipboardController.class);
+		final MapClipboardController clipboardController = mModeController.getExtension(MapClipboardController.class);
 		final NodeModel duplicate = clipboardController.duplicate(node, false);
 		IActor converter = new IActor() {
-			
+
 			@Override
 			public void act() {
 				node.swapData(duplicate);
 				nodeChanged(node);
 			}
-			
+
 			@Override
 			public void undo() {
 				node.swapData(duplicate);
 				nodeChanged(node);
 			}
-			
+
 			@Override
 			public String getDescription() {
 				return "convertClonesToIndependentNodes";
 			}
-			
+
 		};
 		final boolean shouldConvertChildNodes = node.subtreeClones().size() > 1;
 		mModeController.execute(converter, node.getMap());
@@ -456,15 +486,18 @@ public class MMapController extends MapController {
 	private void deleteSingleNode(final NodeModel parentNode, final int index) {
 		final NodeModel node = parentNode.getChildAt(index);
 		final IActor actor = new IActor() {
-        	public void act() {
+        	@Override
+			public void act() {
         		deleteWithoutUndo(parentNode, index);
         	}
 
-        	public String getDescription() {
+        	@Override
+			public String getDescription() {
         		return "delete";
         	}
 
-        	public void undo() {
+        	@Override
+			public void undo() {
 				(Controller.getCurrentModeController().getMapController()).insertNodeIntoWithoutUndo(node, parentNode, index);
         	}
         };
@@ -555,7 +588,7 @@ public class MMapController extends MapController {
 			moveNodeAndItsClones(child, oldParent, newIndex, newParent.isLeft(), false);
 			return;
 		}
-			
+
 		final NodeModel childNode = child;
 		final int oldIndex = oldParent.getIndex(childNode);
 		final int childCount = newParent.getChildCount();
@@ -608,17 +641,20 @@ public class MMapController extends MapController {
                                 final boolean isLeft, final boolean changeSide) {
 		final NodeModel oldParent = child.getParentNode();
 		final int oldIndex = oldParent.getIndex(child);
-		
+
 		final boolean wasLeft = child.isLeft();
 		final IActor actor = new IActor() {
+			@Override
 			public void act() {
 				moveNodeToWithoutUndo(child, newParent, newIndex, isLeft, changeSide);
 			}
 
+			@Override
 			public String getDescription() {
 				return "moveNode";
 			}
 
+			@Override
 			public void undo() {
 				moveNodeToWithoutUndo(child, oldParent, oldIndex, wasLeft, changeSide);
 			}
@@ -661,9 +697,10 @@ public class MMapController extends MapController {
 	public void moveNodesInGivenDirection(NodeModel selected, Collection<NodeModel> movedNodes, final int direction) {
 		final List<NodeModel> movedNodesWithEdges = new SummaryGroupEdgeListAdder(movedNodes).addSummaryEdgeNodes();
 		final Collection<NodeModel> movedNodeSet = new HashSet<NodeModel>(movedNodesWithEdges);
-		
+
         final Comparator<Object> comparator = (direction == -1) ? null : new Comparator<Object>() {
-            public int compare(final Object o1, final Object o2) {
+            @Override
+			public int compare(final Object o1, final Object o2) {
                 final int i1 = ((Integer) o1).intValue();
                 final int i2 = ((Integer) o2).intValue();
                 return i2 - i1;
@@ -727,7 +764,7 @@ public class MMapController extends MapController {
      */
     private List<NodeModel> getSiblingsSortedOnSide(final NodeModel node) {
         final ArrayList<NodeModel> nodes = new ArrayList<NodeModel>(node.getChildCount());
-        for (final NodeModel child : Controller.getCurrentModeController().getMapController().childrenUnfolded(node)) {
+        for (final NodeModel child : node.getChildren()) {
             nodes.add(child);
         }
         if(! node.isRoot()){
@@ -740,7 +777,8 @@ public class MMapController extends MapController {
         }
 
         Collections.sort(nodes, new Comparator<Object>() {
-            public int compare(final Object o1, final Object o2) {
+            @Override
+			public int compare(final Object o1, final Object o2) {
                 if (o1 instanceof NodeModel) {
                     final NodeModel n1 = (NodeModel) o1;
                     if (o2 instanceof NodeModel) {
@@ -782,7 +820,7 @@ public class MMapController extends MapController {
 		return newIndex;
 	}
 
-	public MapModel newModel(NodeModel existingNode) {
+	public MapModel createModel(NodeModel existingNode) {
 	    // use new MMapModel() instead of calling this method with a null arg
 		if(existingNode == null)
 			throw new NullPointerException("null node not allowed.");
@@ -794,14 +832,12 @@ public class MMapController extends MapController {
     }
 
 	@Override
-	public MapModel newModel() {
-		final MMapModel mindMapMapModel = new MMapModel();
-		mindMapMapModel.createNewRoot();
-		fireMapCreated(mindMapMapModel);
-		return mindMapMapModel;
+	public MapModel newMap() {
+		return new MapLoader(getMModeController()).withView().getMap();
 	}
 
 
+
 	@Override
     public void setSaved(final MapModel mapModel, final boolean saved) {
 		final boolean setTitle = saved != mapModel.isSaved() || mapModel.isReadOnly();
@@ -844,9 +880,11 @@ public class MMapController extends MapController {
 		if (component == null)
 			return newNode;
 		component.addFocusListener(new FocusListener() {
+			@Override
 			public void focusLost(FocusEvent e) {
 			}
 
+			@Override
 			public void focusGained(FocusEvent e) {
 				e.getComponent().removeFocusListener(this);
 				((MTextController) textController).edit(newNode, targetNode, true, false, false);
@@ -858,82 +896,46 @@ public class MMapController extends MapController {
 
 	/**@deprecated -- use MMapIO*/
 	@Deprecated
-	public boolean newUntitledMap(final URL url) throws FileNotFoundException, IOException, URISyntaxException, XMLException{
-        try {
-        	Controller.getCurrentController().getViewController().setWaitingCursor(true);
-        	final MapModel newModel = new MMapModel();
-        	UrlManager.getController().load(url, newModel);
-        	newModel.setURL(null);
-        	fireMapCreated(newModel);
-        	newMapView(newModel);
-        	return true;
-        }
-        finally {
-        	Controller.getCurrentController().getViewController().setWaitingCursor(false);
-        }
+	public void newMap(final URL url){
+		new MapLoader(getMModeController()).load(url).unsetMapLocation().withView().getMap();
+	}
+
+	private WeakHashMap<MMapModel, Void> loadedMaps = new WeakHashMap<>();
+
+
+	synchronized public MMapModel getMap(URL url) {
+		for(MMapModel hiddenMap : loadedMaps.keySet()) {
+			if(url.equals(hiddenMap.getURL()))
+				return hiddenMap;
+		}
+		return null;
+	}
+
+
+	synchronized public void addLoadedMap(MMapModel map) {
+		loadedMaps.put(map, null);
+	}
+
+
+
+	public MMapModel createUntitledMap(final URL url) throws IOException, XMLException {
+		return (MMapModel) new MapLoader(getMModeController()).load(url).unsetMapLocation().withView().getMap();
+	}
+
+	public MapModel readMap(URL url) throws FileNotFoundException, XMLParseException, IOException, URISyntaxException {
+		return new MapLoader(getMModeController()).load(url).getMap();
 	}
 
 	/**@throws XMLException
 	 * @deprecated -- use MMapIO*/
 	@Deprecated
 	@Override
-    public boolean newMap(URL url) throws FileNotFoundException, IOException, URISyntaxException, XMLException {
-		// load as documentation map if necessary
-		if(getMModeController().containsExtension(DocuMapAttribute.class)){
-			return newDocumentationMap(url);
-		}
-		final IMapViewManager mapViewManager = Controller.getCurrentController().getMapViewManager();
-		if (mapViewManager.tryToChangeToMapView(url))
-			return false;
+	public void openMap(URL url) {
 		if (AddOnsController.getController().installIfAppropriate(url))
-			return false;
-		URL alternativeURL = null;
-		try {
-			final File file = Compat.urlToFile(url);
-			if(file == null){
-				alternativeURL =  url;
-			}
-			else{
-				if(file.exists()){
-					final MFileManager fileManager = MFileManager.getController(getMModeController());
-					File alternativeFile = fileManager.getAlternativeFile(file, AlternativeFileMode.AUTOSAVE);
-					if(alternativeFile != null){
-						if (alternativeFile.getAbsoluteFile().equals(file.getAbsoluteFile()) )
-							alternativeURL =  url;
-						else
-							alternativeURL = Compat.fileToUrl(alternativeFile);
-					}
-					else
-						return false;
-				}
-				else{
-					alternativeURL = url;
-				}
-			}
-		}
-		catch (MalformedURLException e) {
-		}
-		catch (URISyntaxException e) {
-		}
+			return;
+		new MapLoader(getMModeController()).load(url).withView().getMap();
+	}
 
-		if(alternativeURL == null)
-			return false;
-		Controller.getCurrentController().getViewController().setWaitingCursor(true);
-		try{
-			final MapModel newModel = new MMapModel();
-    		final MFileManager fileManager = MFileManager.getController(getMModeController());
-    		fileManager.loadAndLock(alternativeURL, newModel);
-			newModel.setURL(url);
-			newModel.setSaved(alternativeURL.equals(url));
-			fireMapCreated(newModel);
-			newMapView(newModel);
-			return true;
-		}
-		finally {
-			Controller.getCurrentController().getViewController().setWaitingCursor(false);
-		}
-    }
-	
 	public void newDocumentationMap(final String file) {
 		final NodeAndMapReference nodeAndMapReference = new NodeAndMapReference(file);
 		final ResourceController resourceController = ResourceController.getResourceController();
@@ -951,7 +953,7 @@ public class MMapController extends MapController {
 			try {
 				if (endUrl.getFile().endsWith(".mm")) {
 					Controller.getCurrentController().selectMode(MModeController.MODENAME);
-					newDocumentationMap(endUrl);
+					openDocumentationMap(endUrl);
 					if(nodeAndMapReference.hasNodeReference())
 						select(nodeAndMapReference.getNodeReference());
 
@@ -968,68 +970,56 @@ public class MMapController extends MapController {
 			LogUtils.warn(e1);
 		}
 	}
-	
+
 
 
 	/**@throws XMLException
 	 * @deprecated -- use MMapIO*/
 	@Deprecated
-	public boolean newDocumentationMap(final URL url) throws FileNotFoundException, IOException, URISyntaxException, XMLException{
-		final IMapViewManager mapViewManager = Controller.getCurrentController().getMapViewManager();
-		if (mapViewManager.tryToChangeToMapView(url))
-			return false;
-        try {
-        	Controller.getCurrentController().getViewController().setWaitingCursor(true);
-        	final MapModel newModel = new MMapModel();
-        	newModel.addExtension(DocuMapAttribute.instance);
-        	UrlManager.getController().load(url, newModel);
-        	newModel.setReadOnly(true);
-        	fireMapCreated(newModel);
-        	newMapView(newModel);
-        	newModel.setSaved(true);
-        	return true;
-        }
-        finally {
-        	Controller.getCurrentController().getViewController().setWaitingCursor(false);
-        }
+	public void openDocumentationMap(final URL url) throws FileNotFoundException, IOException, URISyntaxException, XMLException{
+		new MapLoader(getMModeController()).load(url).withView().asDocumentation().getMap();
 	}
 
 	/**@throws XMLException
 	 * @deprecated -- use MMapIO*/
 	@Deprecated
-    public boolean restoreCurrentMap() throws FileNotFoundException, IOException, URISyntaxException, XMLException {
+    public void restoreCurrentMap() throws FileNotFoundException, IOException, URISyntaxException, XMLException {
 	    final Controller controller = Controller.getCurrentController();
         final MapModel map = controller.getMap();
         final URL url = map.getURL();
         if(url == null){
         	UITools.errorMessage(TextUtils.getText("map_not_saved"));
-        	return false;
+        	return;
         }
 
 		if(map.containsExtension(DocuMapAttribute.class)){
 			closeWithoutSaving(map);
-			return newDocumentationMap(url);
+			openDocumentationMap(url);
+			return;
 		}
 
 		final URL alternativeURL = MFileManager.getController(getMModeController()).getAlternativeURL(url, AlternativeFileMode.ALL);
 		if(alternativeURL == null)
-			return false;
+			return;
 		controller.getViewController().setWaitingCursor(true);
 		try{
-			final MapModel newModel = new MMapModel();
+			map.releaseResources();
+			final MMapModel newModel = new MMapModel();
 			((MFileManager)MFileManager.getController()).loadAndLock(alternativeURL, newModel);
 			newModel.setURL(url);
 			newModel.setSaved(alternativeURL.equals(url));
 			fireMapCreated(newModel);
+			addLoadedMap(newModel);
 			closeWithoutSaving(map);
-			newMapView(newModel);
-			return true;
+			newModel.enableAutosave();
+			createMapView(newModel);
+			return;
 		}
 		finally {
 			controller.getViewController().setWaitingCursor(false);
 		}
 	}
-	
+
 	@Override
 	protected void setFoldingState(final NodeModel node, final boolean folded) {
 		final IMapViewManager mapViewManager = Controller.getCurrentController().getMapViewManager();
@@ -1043,12 +1033,12 @@ public class MMapController extends MapController {
 					unfoldHiddenChildren(node);
 					MMapController.super.setFoldingState(node, wasFolded);
 				}
-				
+
 				@Override
 				public String getDescription() {
 					return "setFoldingState";
 				}
-				
+
 				@Override
 				public void act() {
 					unfoldHiddenChildren(node);
@@ -1060,9 +1050,9 @@ public class MMapController extends MapController {
 		else
 			super.setFoldingState(node, folded);
 	}
-	
+
 	static private final List<String> foldingSavedOptions = Arrays.asList(NodeBuilder.RESOURCES_ALWAYS_SAVE_FOLDING, NodeBuilder.RESOURCES_SAVE_FOLDING_IF_MAP_IS_CHANGED);
-	
+
 	private boolean isFoldingPersistent() {
 	    final ResourceController resourceController = ResourceController.getResourceController();
 		return foldingSavedOptions.contains(resourceController.getProperty(NodeBuilder.RESOURCES_SAVE_FOLDING));
