@@ -33,7 +33,6 @@ import java.io.IOException;
 import java.io.StringReader;
 import java.io.StringWriter;
 import java.net.URI;
-import java.net.URISyntaxException;
 import java.util.Collection;
 import java.util.LinkedHashSet;
 import java.util.LinkedList;
@@ -505,27 +504,6 @@ public class MTextController extends TextController {
 		return parseData;
 	}
 
-	/** converts strings to date, number or URI if possible. All other data types are left unchanged. */
-	public Object guessObjectOrURI(final Object object, final String oldFormat) {
-		Object guessedObject = guessObject(object, oldFormat);
-		if (guessedObject == object && !(object instanceof URI) && matchUriPattern(object)) {
-			try {
-				return new URI((String) object);
-			}
-			catch (URISyntaxException e) {
-				LogUtils.warn("URI regular expression does not match URI parser for " + object);
-				return object;
-			}
-		}
-		return guessedObject;
-	}
-
-	private boolean matchUriPattern(Object object) {
-		if (!(object instanceof String))
-			return false;
-		return TextUtils.matchUriPattern((String) object);
-	}
-
 	public void setNodeText(final NodeModel node, final String newText) {
 		setNodeObject(node, newText);
 	}
