@@ -31,7 +31,9 @@ import java.util.List;
 import java.util.Map;
 
 import javax.swing.JComboBox;
+import javax.swing.JComponent;
 
+import org.freeplane.core.extension.Configurable;
 import org.freeplane.features.map.IMapSelection;
 import org.freeplane.features.map.IMapSelection.NodePosition;
 import org.freeplane.features.map.IMapSelectionListener;
@@ -56,43 +58,30 @@ public interface IMapViewManager {
 	public boolean changeToMapView(final Component newMapView);
 
 	public boolean changeToMapView(final String mapViewDisplayName);
-	
+
 	public void changeToMap(MapModel map);
 
 	public boolean changeToMode(final String modeName);
 
-	/**
-	 * Checks, whether or not a given url is already opened. Unlike
-	 * tryToChangeToMapView, it does not consider the map+extension identifiers
-	 * nor switches to the mapView.
-	 *
-	 * @return null, if not found, the map+extension identifier otherwise.
-	 */
 	public String checkIfFileIsAlreadyOpened(final URL urlToCheck) throws MalformedURLException;
 
-	/**
-	 * Close the currently active map, return false if closing canceled.
-	 *
-	 * @param withoutSave
-	 *            forces the closing without any save actions.
-	 */
 	public boolean close();
 	public boolean close(final Component view);
-	
+
 	public String createHtmlMap();
 
 	public RenderedImage createImage(int dpi);
 
 	public RenderedImage createImage(final Dimension slideSize, NodeModel placedNode, NodePosition placedNodePosition, int imageResolutionInDpi);
-	
+
 	public Color getBackgroundColor(NodeModel node);
 
 	public Component getComponent(NodeModel node);
-	
+
 	public boolean isFoldedOnCurrentView(NodeModel node);
 
 	public void displayOnCurrentView(NodeModel node);
-	
+
 	public void setFoldedOnCurrentView(NodeModel node, boolean folded);
 
 	public Font getFont(NodeModel node);
@@ -104,7 +93,9 @@ public interface IMapViewManager {
 
 	public IMapSelection getMapSelection();
 
-	public Component getMapViewComponent();
+	public JComponent getMapViewComponent();
+
+	public Configurable getMapViewConfiguration();
 
 	public List<? extends Component> getMapViewVector();
 
@@ -161,12 +152,16 @@ public interface IMapViewManager {
 
 	public boolean hasHiddenChildren(NodeModel selected);
 
+	int getHiddenChildCount(NodeModel node);
+
 	public boolean unfoldHiddenChildren(NodeModel node);
 
 	public void hideChildren(NodeModel node);
 
 	public boolean showHiddenNode(NodeModel child);
-	
+
 	public boolean isSpotlightEnabled();
 
+	public boolean isHeadless();
+
 }
