@@ -418,9 +418,22 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 	        URISyntaxException {
 		final File file = Compat.urlToFile(url);
 		if (file == null) {
-			super.loadCatchExceptions(url, map);
-			return;
+			loadCatchExceptions(url, map);
 		}
+		else {
+			lock(map, file);
+			if (file.length() != 0) {
+				//DOCEAR - fixed: set the file for the map before parsing the xml, necessary for some events
+				setFile(map, file);
+				NodeModel root = loadTree(map, file);
+				assert (map.getRootNode() == root);
+			}
+			if (map.getRootNode() == null)
+				map.createNewRoot();
+		}
+	}
+
+	public void lock(final MapModel map, final File file) throws FileNotFoundException {
 		if (!file.exists()) {
 			throw new FileNotFoundException(TextUtils.format("file_not_found", file.getPath()));
 		}
@@ -445,14 +458,6 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 			    TextUtils.format("locking_failed_by_open", file.getName()));
 			map.setReadOnly(true);
 		}
-		if (file.length() != 0) {
-			//DOCEAR - fixed: set the file for the map before parsing the xml, necessary for some events
-			setFile(map, file);
-			NodeModel root = loadTree(map, file);
-			assert (map.getRootNode() == root);
-		}
-		if (map.getRootNode() == null)
-			map.createNewRoot();
 	}
 
 	public URL getAlternativeURL(final URL url, AlternativeFileMode mode) {
@@ -470,8 +475,6 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		}
 		catch (MalformedURLException e) {
 		}
-		catch (URISyntaxException e) {
-		}
 		return null;
 	}
 
@@ -493,8 +496,6 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		return selectedFile;
 	}
 
-	/**@deprecated -- use MMapIO*/
-	@Deprecated
 	public NodeModel loadTree(final MapModel map, final File file) throws XMLParseException, IOException {
 		try {
 			final NodeModel rootNode = loadTreeImpl(map, file);
@@ -503,8 +504,8 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		catch (final Exception ex) {
 			final String errorMessage = "Error while parsing file:" + file;
 			LogUtils.warn(errorMessage, ex);
-			UITools.errorMessage(errorMessage);
 			final NodeModel result = new NodeModel(map);
+			map.setRoot(result);
 			result.setText(errorMessage);
 			return result;
 		}
@@ -569,8 +570,6 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		super.loadURL(relative);
 	}
 
-	/**@deprecated -- use MapIO*/
-	@Deprecated
 	public void open() {
 		final JFileChooser chooser = getFileChooser(false);
 		chooser.setMultiSelectionEnabled(true);
@@ -585,7 +584,7 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 			final File theFile = selectedFiles[i];
 			try {
 				setLastCurrentDir(theFile.getParentFile());
-				Controller.getCurrentModeController().getMapController().newMap(Compat.fileToUrl(theFile));
+				Controller.getCurrentModeController().getMapController().openMap(Compat.fileToUrl(theFile));
 			}
 			catch (final Exception ex) {
 				handleLoadingException(ex);
@@ -595,19 +594,16 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		Controller.getCurrentController().getMapViewManager().setMapTitles();
 	}
 
-	/**@deprecated -- use MMapIO*/
-	@Deprecated
 	public MapModel newMapFromDefaultTemplate() {
 		return AccessController.doPrivileged(new PrivilegedAction<MapModel>() {
 			@Override
 			public MapModel run() {
 				final File file = chosenTemplateFile();
 				if (file != null) {
-					return newMapFromTemplate(file);
+					return openUntitledMap(file);
 				}
 				final MapController mapController = Controller.getCurrentModeController().getMapController();
 				final MapModel map = mapController.newMap();
-				mapController.setSaved(map, true);
 				return map;
 			}
 		});
@@ -683,9 +679,7 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		return allUserTemplates;
 	}
 
-	/**@deprecated -- use MMapIO*/
-	@Deprecated
-	public MapModel newMapFromTemplate(final File startFile) {
+	public MapModel openUntitledMap(final File startFile) {
 		return AccessController.doPrivileged(new PrivilegedAction<MapModel>() {
 			@Override
 			public MapModel run() {
@@ -709,14 +703,9 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 				try {
 					final MMapController mapController = (MMapController) Controller.getCurrentModeController()
 					    .getMapController();
-					mapController.newUntitledMap(Compat.fileToUrl(file));
+					mapController.newMap(Compat.fileToUrl(file));
 					final Controller controller = Controller.getCurrentController();
 					final MapModel map = controller.getMap();
-					final Object rootText = map.getRootNode().getUserObject();
-					if (rootText instanceof TranslatedObject) {
-						map.getRootNode().setText(rootText.toString());
-					}
-					controller.getModeController().getMapController().setSaved(map, true);
 					return map;
 				}
 				catch (Exception e) {
@@ -727,34 +716,6 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		});
 	}
 
-	/**@deprecated -- use MMapIO*/
-	@Deprecated
-	public void saveAsUserTemplate() {
-		final JFileChooser chooser = new JFileChooser();
-		final FileFilter filter = getFileFilter();
-		chooser.addChoosableFileFilter(filter);
-		chooser.setFileFilter(filter);
-		final File userTemplates = defaultUserTemplateDir();
-		chooser.setCurrentDirectory(userTemplates);
-		final int returnVal = chooser
-		    .showOpenDialog(Controller.getCurrentController().getMapViewManager().getMapViewComponent());
-		if (returnVal != JFileChooser.APPROVE_OPTION) {
-			return;
-		}
-		File file = chooser.getSelectedFile();
-		if (file.exists()) {
-			final int overwriteMap = JOptionPane.showConfirmDialog(Controller.getCurrentController()
-			    .getMapViewManager().getMapViewComponent(), TextUtils.getText("map_already_exists"), "Freeplane",
-			    JOptionPane.YES_NO_OPTION);
-			if (overwriteMap != JOptionPane.YES_OPTION) {
-				return;
-			}
-		}
-		saveInternal((MMapModel) Controller.getCurrentController().getMap(), file, false);
-	}
-
-	/**@deprecated -- use MMapIO*/
-	@Deprecated
 	public boolean save(final MapModel map) {
 		if (map == null || map.isSaved()) {
 			return true;
@@ -767,8 +728,6 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		}
 	}
 
-	/**@deprecated -- use MMapIO*/
-	@Deprecated
 	public boolean save(final MapModel map, final File file) {
 		if (file == null) {
 			return saveAs(map);
@@ -791,7 +750,16 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 			    TextUtils.format("locking_failed_by_save_as", file.getName()));
 			return false;
 		}
+		if (file.exists() && !file.canWrite()) {
+			JOptionPane.showMessageDialog(Controller.getCurrentController()
+			    .getMapViewManager().getMapViewComponent(),
+			    TextUtils.format("SaveAs_toReadonlyMsg", file),
+			    TextUtils.getText("SaveAs_toReadonlyTitle"),
+			    JOptionPane.WARNING_MESSAGE);
+			return false;
+		}
 		final URL urlBefore = map.getURL();
+		setFile(map, file);
 		final boolean saved = saveInternal((MMapModel) map, file, false);
 		if (!saved) {
 			return false;
@@ -799,13 +767,12 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 		map.setReadOnly(false);
 		final URL urlAfter = map.getURL();
 		final MMapController mapController = (MMapController) Controller.getCurrentModeController().getMapController();
-		mapController.fireMapChanged(new MapChangeEvent(this, map, UrlManager.MAP_URL, urlBefore, urlAfter));
+		if(! urlAfter.equals(urlBefore))
+			mapController.fireMapChanged(new MapChangeEvent(this, map, UrlManager.MAP_URL, urlBefore, urlAfter, false));
 		mapController.setSaved(map, true);
 		return true;
 	}
 
-	/**@deprecated -- use MMapIO*/
-	@Deprecated
 	public boolean saveAs(final MapModel map) {
 		final JFileChooser chooser = getFileChooser(true);
 		if (getMapsParentFile(map) == null) {
@@ -863,25 +830,11 @@ public class MFileManager extends UrlManager implements IMapViewChangeListener {
 	 * of temporary (internal) files.
 	 */
 	boolean saveInternal(final MMapModel map, final File file, final boolean isInternal) {
-		if (file.exists() && !file.canWrite()) {
-			JOptionPane.showMessageDialog(Controller.getCurrentController()
-			    .getMapViewManager().getMapViewComponent(),
-			    TextUtils.format("SaveAs_toReadonlyMsg", file),
-			    TextUtils.getText("SaveAs_toReadonlyTitle"),
-			    JOptionPane.WARNING_MESSAGE);
-			return false;
-		}
 		try {
 			if (map.getTimerForAutomaticSaving() != null) {
 				map.getTimerForAutomaticSaving().cancel();
 			}
-			if (!isInternal) {
-				setFile(map, file);
-			}
 			writeToFile(map, file);
-			if (!isInternal) {
-				map.setSaved(true);
-			}
 			map.scheduleTimerForAutomaticSaving();
 			return true;
 		}
