@@ -178,7 +178,7 @@ public class HeadlessUIController extends FrameController {
 
 	@Override
 	public void setWaitingCursor(boolean b) {
-		throw methodNotImplementedException();
+		// do nothing
 	}
 
 	@Override
@@ -186,11 +186,6 @@ public class HeadlessUIController extends FrameController {
 		throw methodNotImplementedException();
 	}
 
-	@Override
-	public String completeVisiblePropertyKey(JComponent toolBar) {
-		throw methodNotImplementedException();
-	}
-
 	@Override
 	public void addObjectTypeInfo(Object value) {
 		throw methodNotImplementedException();
@@ -214,6 +209,7 @@ public class HeadlessUIController extends FrameController {
 	@Override
 	public void invokeAndWait(Runnable runnable) throws InterruptedException, InvocationTargetException {
 		try {
+			if(! worker.isShutdown())
 			worker.submit(runnable).get();
 		}
 		catch (ExecutionException e) {
@@ -271,4 +267,8 @@ public class HeadlessUIController extends FrameController {
 	private RuntimeException methodNotImplementedException() {
 		return new RuntimeException("Method not implemented");
 	}
+
+	public void shutdown() {
+		worker.shutdown();
+	}
 }
