@@ -33,9 +33,12 @@ import org.freeplane.core.ui.SetAcceleratorOnNextClickAction;
 import org.freeplane.core.ui.ShowSelectionAsRectangleAction;
 import org.freeplane.core.ui.components.FreeplaneToolBar;
 import org.freeplane.core.ui.components.UITools;
+import org.freeplane.core.ui.components.resizer.UIComponentVisibilityDispatcher;
 import org.freeplane.features.attribute.AttributeController;
 import org.freeplane.features.attribute.ModelessAttributeController;
 import org.freeplane.features.attribute.mindmapmode.MAttributeController;
+import org.freeplane.features.clipboard.ClipboardControllers;
+import org.freeplane.features.clipboard.mindmapmode.MClipboardControllers;
 import org.freeplane.features.cloud.CloudController;
 import org.freeplane.features.cloud.mindmapmode.MCloudController;
 import org.freeplane.features.edge.EdgeController;
@@ -56,7 +59,6 @@ import org.freeplane.features.map.MapController;
 import org.freeplane.features.map.NodeChangeEvent;
 import org.freeplane.features.map.NodeModel;
 import org.freeplane.features.map.mindmapmode.MMapController;
-import org.freeplane.features.mapio.mindmapmode.MMapIO;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.ModeController;
 import org.freeplane.features.nodelocation.LocationController;
@@ -77,7 +79,6 @@ import org.freeplane.features.styles.mindmapmode.styleeditorpanel.StyleEditorPan
 import org.freeplane.features.text.TextController;
 import org.freeplane.features.text.mindmapmode.MTextController;
 import org.freeplane.features.ui.ToggleToolbarAction;
-import org.freeplane.features.ui.UIComponentVisibilityDispatcher;
 import org.freeplane.features.ui.ViewController;
 import org.freeplane.features.url.mindmapmode.MFileManager;
 import org.freeplane.view.swing.map.MapViewController;
@@ -120,6 +121,7 @@ public class SModeControllerFactory {
 		controller.addAction(new ShowSelectionAsRectangleAction());
 		modeController = new SModeController(controller);
 		controller.selectModeForBuild(modeController);
+		ClipboardControllers.install(new MClipboardControllers());
 		modeController.addAction(new NewUserStyleAction());
 		modeController.addAction(new DeleteUserStyleAction());
 		modeController.addAction(new NewLevelStyleAction());
@@ -143,7 +145,6 @@ public class SModeControllerFactory {
 		NoteController.install(new MNoteController(modeController));
 		LinkController.install(new MLinkController(modeController));
 		MFileManager.install(new MFileManager());
-		MMapIO.install(modeController);
 		final MLogicalStyleController logicalStyleController = new MLogicalStyleController(modeController);
 		logicalStyleController.initS();
 		LogicalStyleController.install(logicalStyleController);
@@ -158,7 +159,7 @@ public class SModeControllerFactory {
 		final JPopupMenu popupmenu = new JPopupMenu();
 		userInputListenerFactory.setNodePopupMenu(popupmenu);
 		final FreeplaneToolBar toolBar = new FreeplaneToolBar("main_toolbar", SwingConstants.HORIZONTAL);
-		UIComponentVisibilityDispatcher.install(viewController, toolBar, "toolbarVisible");
+		UIComponentVisibilityDispatcher.install(toolBar, "dialog_toolbarVisible");
 		userInputListenerFactory.addToolBar("/main_toolbar", ViewController.TOP, toolBar);
 		userInputListenerFactory.addToolBar("/icon_toolbar", ViewController.LEFT, ((MIconController) IconController
 		    .getController()).getIconToolBarScrollPane());
@@ -223,7 +224,7 @@ public class SModeControllerFactory {
 		UITools.setScrollbarIncrement(styleScrollPane);
 		//		styleEditorPanel.setPreferredSize(new Dimension(200, 200));
 		userInputListenerFactory.addToolBar("/format", ViewController.RIGHT, styleScrollPane);
-		UIComponentVisibilityDispatcher.install(viewController, styleScrollPane, "styleScrollPaneVisible");
+		UIComponentVisibilityDispatcher.install(styleScrollPane, "dialog_styleScrollPaneVisible");
 		modeController.addExtension(MUIFactory.class, new MUIFactory());
 		final Set<String> emptySet = Collections.emptySet();
 		modeController.updateMenus("/xml/stylemodemenu.xml", emptySet);
