@@ -79,15 +79,15 @@ import org.freeplane.features.text.TextController;
 import org.freeplane.features.text.mindmapmode.MTextController;
 
 import com.jgoodies.forms.builder.DefaultFormBuilder;
-import com.jgoodies.forms.layout.FormSpecs;
 import com.jgoodies.forms.layout.FormLayout;
+import com.jgoodies.forms.layout.FormSpecs;
 
 /**
  * @author foltin
  */
 class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 
-	class JTimePanel extends JPanel 
+	class JTimePanel extends JPanel
 	{
         private static final long serialVersionUID = 1L;
 		private JButton setReminderButton;
@@ -104,7 +104,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 	        final NodeModel selected = reminderHook.getModeController().getMapController().getSelectedNode();
 	        update(selected);
         }
-		
+
 		public void update(NodeModel node){
 			if(node == null)
 				return;
@@ -157,7 +157,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 			calendarComponent.getDayChooser().addPropertyChangeListener(TimeManagement.this);
 			calendarContainer.setAlignmentX(0.5f);
 			add(calendarContainer);
-			
+
 			DefaultFormBuilder btnBuilder = new DefaultFormBuilder(new FormLayout(FormSpecs.GROWING_BUTTON_COLSPEC.toString(), ""));
 			 btnBuilder.getLayout().addGroupedColumn(btnBuilder.getColumnCount());
 			 for(int i = 1; i< colCount; i++){
@@ -167,8 +167,9 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 			}
 
 			{
-				final JButton todayButton = new JButton(getResourceString("plugins/TimeManagement.xml_todayButton"));
+				final JButton todayButton = new JButton(getResourceString("reminder.todayButton"));
 				todayButton.addActionListener(new ActionListener() {
+					@Override
 					public void actionPerformed(final ActionEvent arg0) {
 						final Calendar currentTime = Calendar.getInstance();
 						currentTime.set(Calendar.SECOND, 0);
@@ -183,7 +184,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 				btnBuilder.append(dateFormatChooser);
 			}
 			{
-				final JButton appendButton = new JButton(getResourceString("plugins/TimeManagement.xml_appendButton"));
+				final JButton appendButton = new JButton(getResourceString("reminder.appendButton"));
 				if (dialog == null) {
 					appendButton.setFocusable(false);
 				}
@@ -197,7 +198,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 			}
 			{
 				scriptEditor = null;
-				IScriptEditorStarter editor = (IScriptEditorStarter) reminderHook.getModeController().getExtension(IScriptEditorStarter.class);
+				IScriptEditorStarter editor = reminderHook.getModeController().getExtension(IScriptEditorStarter.class);
 				if(editor != null){
 					scriptEditor = editor.createComboBoxEditor(new Dimension(600, 400));
 					Component scriptButton = scriptEditor.getEditorComponent();
@@ -205,8 +206,8 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 				}
 			}
 			{
-				setReminderButton = new JButton(getResourceString("plugins/TimeManagement.xml_reminderButton"));
-				setReminderButton.setToolTipText(getResourceString("plugins/TimeManagement.xml_reminderButton_tooltip"));
+				setReminderButton = new JButton(getResourceString("reminder.reminderButton"));
+				setReminderButton.setToolTipText(getResourceString("reminder.reminderButton.tooltip"));
 				setReminderButton.addMouseListener(new MouseAdapter() {
 					@Override
 	                public void mouseClicked(MouseEvent e) {
@@ -217,15 +218,15 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 			}
 			{
 				remindLaterButton = new JButton(
-				    getResourceString("plugins/TimeManagement.xml_remindLaterButton"));
-				remindLaterButton.setToolTipText(getResourceString("plugins/TimeManagement.xml_remindLaterButton_tooltip"));
+				    getResourceString("reminder.remindLaterButton"));
+				remindLaterButton.setToolTipText(getResourceString("reminder.remindLaterButton.tooltip"));
 				remindLaterButton.addMouseListener(new MouseAdapter() {
 
 					@Override
 	                public void mouseClicked(MouseEvent e) {
 						remindLaterReminder();
 	               }
-					
+
 				});
 				btnBuilder.append(remindLaterButton);
 			}
@@ -235,20 +236,20 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 			}
 			{
 				removeReminderButton = new JButton(
-				    getResourceString("plugins/TimeManagement.xml_removeReminderButton"));
-				removeReminderButton.setToolTipText(getResourceString("plugins/TimeManagement.xml_removeReminderButton_tooltip"));
+				    getResourceString("reminder.removeReminderButton"));
+				removeReminderButton.setToolTipText(getResourceString("reminder.removeReminderButton.tooltip"));
 				removeReminderButton.addMouseListener(new MouseAdapter() {
 
 					@Override
 	                public void mouseClicked(MouseEvent e) {
 						removeReminder();
 	               }
-					
+
 				});
 				btnBuilder.append(removeReminderButton);
 			}
 			if (dialog != null) {
-				final JButton cancelButton = new JButton(getResourceString("plugins/TimeManagement.xml_closeButton"));
+				final JButton cancelButton = new JButton(getResourceString("reminder.closeButton"));
 				cancelButton.addMouseListener(new MouseAdapter() {
 
 					@Override
@@ -279,7 +280,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 					if(oldReminderTime > System.currentTimeMillis()){
 						final Object[] messageArguments = { new Date(oldReminderTime), date };
 						final MessageFormat formatter = new MessageFormat(
-							getResourceString("plugins/TimeManagement.xml_reminderNode_onlyOneDate"));
+							getResourceString("reminder.reminderNode_onlyOneDate"));
 						final String message = formatter.format(messageArguments);
 						final int result = JOptionPane.showConfirmDialog(controller.getViewController().getCurrentRootComponent(), message,
 							"Freeplane", JOptionPane.YES_NO_OPTION);
@@ -287,6 +288,8 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 							return;
 						}
 					}
+					if(scriptEditor == null)
+						script = alreadyPresentHook.getScript();
 					reminderHook.undoableToggleHook(node);
 				}
 				final ReminderExtension reminderExtension = new ReminderExtension(node);
@@ -326,10 +329,8 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 		Controller.getCurrentController().getMapViewManager().addMapSelectionListener(this);
 	}
 
-	
-	public void afterMapChange(final MapModel oldMap, final MapModel newMap) {
-	}
 
+	@Override
 	public void beforeMapChange(final MapModel oldMap, final MapModel newMap) {
 		disposeDialog();
 	}
@@ -364,6 +365,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 	}
 
 
+	@Override
 	public void propertyChange(final PropertyChangeEvent event) {
 		if (event.getPropertyName().equals(JDayChooser.DAY_PROPERTY)) {
 		}
@@ -378,15 +380,18 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 		dialog = new JDialog(UITools.getCurrentFrame(), false /*not modal*/);
 		final JTimePanel timePanel =createTimePanel(dialog, true, 4);
 		nodeSelectionListener = new INodeSelectionListener() {
+			@Override
 			public void onSelect(NodeModel node) {
 				timePanel.update(node);
 			}
-			
+
+			@Override
 			public void onDeselect(NodeModel node) {
 			}
 		};
 		getMindMapController().getMapController().addNodeSelectionListener(nodeSelectionListener);
 		nodeChangeListener = new INodeChangeListener() {
+			@Override
 			public void nodeChanged(NodeChangeEvent event) {
 				final NodeModel node = event.getNode();
 				if(event.getProperty().equals(ReminderExtension.class) && node.equals(getMindMapController().getMapController().getSelectedNode()))
@@ -394,8 +399,8 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 			}
 		};
 		getMindMapController().getMapController().addNodeChangeListener(nodeChangeListener);
-		
-		dialog.setTitle(getResourceString("plugins/TimeManagement.xml_WindowTitle"));
+
+		dialog.setTitle(getResourceString("reminder.WindowTitle"));
 		dialog.setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
 		dialog.addWindowListener(new WindowAdapter() {
 			@Override
@@ -405,10 +410,11 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 		});
 		final Action action = new AbstractAction() {
 			/**
-			 * 
+			 *
 			 */
 			private static final long serialVersionUID = 1L;
 
+			@Override
 			public void actionPerformed(final ActionEvent arg0) {
 				disposeDialog();
 			}
@@ -419,7 +425,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 		UITools.setBounds(dialog, -1, -1, dialog.getWidth(), dialog.getHeight());
 		dialog.setVisible(true);
 	}
-	
+
 	public JTimePanel createTimePanel(final Dialog dialog, boolean useTriple, int colCount) {
 		if (this.calendar == null) {
 			this.calendar = Calendar.getInstance();
@@ -442,6 +448,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 				return dateFormat;
 			}
 
+			@Override
 			public String toString() {
 				return dateFormat.formatObject(getCalendarDate()).toString();
 			}
@@ -467,6 +474,7 @@ class TimeManagement implements PropertyChangeListener, IMapSelectionListener {
 			dateFormatChooser.setSelectedIndex(selectedIndex);
 		}
 		dateFormatChooser.addItemListener(new ItemListener() {
+			@Override
 			public void itemStateChanged(final ItemEvent e) {
 				dateFormat = ((DateFormatComboBoxElement) e.getItem()).getDateFormat();
 				final Component focusOwner = KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusOwner();
