@@ -23,15 +23,12 @@ import java.awt.Color;
 import java.awt.Component;
 import java.awt.Container;
 import java.awt.Dimension;
-import java.awt.EventQueue;
 import java.awt.Font;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.KeyboardFocusManager;
 import java.awt.Window;
 import java.awt.event.ActionEvent;
-import java.awt.event.FocusEvent;
-import java.awt.event.FocusListener;
 import java.awt.event.HierarchyEvent;
 import java.awt.event.HierarchyListener;
 import java.awt.event.InputEvent;
@@ -39,23 +36,38 @@ import java.awt.event.KeyEvent;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
+import java.net.MalformedURLException;
 import java.net.URI;
+import java.net.URL;
 import java.util.EventObject;
+import java.util.Set;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
+import javax.swing.AbstractAction;
 import javax.swing.AbstractCellEditor;
+import javax.swing.Action;
+import javax.swing.ActionMap;
 import javax.swing.BorderFactory;
 import javax.swing.ComboBoxEditor;
 import javax.swing.ComboBoxModel;
 import javax.swing.DefaultCellEditor;
 import javax.swing.DefaultComboBoxModel;
 import javax.swing.Icon;
+import javax.swing.InputMap;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JFrame;
 import javax.swing.JOptionPane;
+import javax.swing.JScrollPane;
 import javax.swing.JTable;
+import javax.swing.JToolTip;
+import javax.swing.JViewport;
 import javax.swing.KeyStroke;
+import javax.swing.ListSelectionModel;
 import javax.swing.SwingUtilities;
+import javax.swing.ToolTipManager;
+import javax.swing.TransferHandler;
 import javax.swing.border.Border;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ListSelectionEvent;
@@ -70,18 +82,16 @@ import org.freeplane.core.ui.LengthUnits;
 import org.freeplane.core.ui.components.JComboBoxWithBorder;
 import org.freeplane.core.ui.components.TypedListCellRenderer;
 import org.freeplane.core.ui.components.UITools;
+import org.freeplane.features.attribute.AttributeController;
 import org.freeplane.features.attribute.AttributeRegistry;
 import org.freeplane.features.attribute.AttributeTableLayoutModel;
 import org.freeplane.features.attribute.ColumnWidthChangeEvent;
-import org.freeplane.features.attribute.IAttributeTableModel;
 import org.freeplane.features.attribute.IColumnWidthChangeListener;
-import org.freeplane.features.attribute.NodeAttributeTableModel;
 import org.freeplane.features.edge.EdgeModel;
 import org.freeplane.features.format.FormattedObject;
 import org.freeplane.features.format.IFormattedObject;
 import org.freeplane.features.format.PatternFormat;
 import org.freeplane.features.link.LinkController;
-import org.freeplane.features.map.MapController;
 import org.freeplane.features.map.NodeModel;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.ModeController;
@@ -94,7 +104,9 @@ import org.freeplane.features.text.mindmapmode.EditNodeBase.EditedComponent;
 import org.freeplane.features.text.mindmapmode.EditNodeBase.IEditControl;
 import org.freeplane.features.text.mindmapmode.MTextController;
 import org.freeplane.features.ui.ViewController;
+import org.freeplane.view.swing.map.FreeplaneTooltip;
 import org.freeplane.view.swing.map.MapView;
+import org.freeplane.view.swing.map.NodeTooltipManager;
 import org.freeplane.view.swing.map.NodeView;
 
 
@@ -105,11 +117,22 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	private static final String EDITING_STOPPED = AttributeTable.class.getName() + ".editingStopped";
 	private static int CLICK_COUNT_TO_START = 2;
 
+	private static final class EditCellAction extends AbstractAction {
+		@Override
+		public void actionPerformed(ActionEvent e) {
+			AttributeTable table = (AttributeTable) e.getSource();
+			final int selectedRow = table.getSelectedRow();
+			final int selectedColumn = table.getSelectedColumn();
+			if(selectedColumn >= 0 && selectedRow >= 0)
+				table.editCellAt(selectedRow, selectedColumn, e);
+		}
+	}
 	private static final class TableHeaderRendererImpl implements TableCellRenderer {
 		final private TableCellRenderer delegate;
 		TableHeaderRendererImpl(TableCellRenderer renderer){
 			this.delegate = renderer;
 		}
+		@Override
 		public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus,
 				int row, int column) {
 			final Component c = delegate.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
@@ -138,107 +161,41 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		public void mouseReleased(final MouseEvent e) {
 			final JTableHeader header = (JTableHeader) e.getSource();
 			final AttributeTable table = (AttributeTable) header.getTable();
-			final float zoom = table.attributeView.getMapView().getZoom();
-			final AttributeTableModelDecoratorAdapter model = (AttributeTableModelDecoratorAdapter) table
-			.getModel();
-			for (int col = 0; col < table.getColumnCount(); col++) {
-				final int modelColumnWidth = model.getColumnWidth(col).toBaseUnitsRounded();
-				final int currentColumnWidth = Math.round(table.getColumnModel().getColumn(col).getWidth() / zoom);
-				if (modelColumnWidth != currentColumnWidth) {
-					model.setColumnWidth(col, LengthUnits.pixelsInPt(currentColumnWidth));
+			if(table.getNodeViewAncestor() != null) {
+				final float zoom = table.attributeView.getMapView().getZoom();
+				final AttributeTableModel model = (AttributeTableModel) table
+						.getModel();
+				for (int col = 0; col < table.getColumnCount(); col++) {
+					final int modelColumnWidth = model.getColumnWidth(col).toBaseUnitsRounded();
+					final int currentColumnWidth = Math.round(table.getColumnModel().getColumn(col).getWidth() / zoom);
+					if (modelColumnWidth != currentColumnWidth) {
+						model.setColumnWidth(col, LengthUnits.pixelsInPt(currentColumnWidth));
+					}
 				}
 			}
 		}
 	}
 
-	static private class MyFocusListener implements FocusListener {
-		private AttributeTable focusedTable;
+	private static AttributeSelectionChangeListener globalFocusChangeListener;
 
-		/*
-		 * (non-Javadoc)
-		 * @see
-		 * java.awt.event.FocusListener#focusGained(java.awt.event.FocusEvent)
-		 */
-		public void focusGained(final FocusEvent event) {
-			final Component source = (Component) event.getSource();
-			event.getOppositeComponent();
-			if (source instanceof AttributeTable) {
-				focusedTable = (AttributeTable) source;
-			}
-			else {
-				focusedTable = (AttributeTable) SwingUtilities.getAncestorOfClass(AttributeTable.class, source);
-			}
-			if(focusedTable != null){
-			    focusedTable.setSelectedCellTypeInfo();
-			}
-			EventQueue.invokeLater(new Runnable() {
-				public void run() {
-					if (focusedTable != null) {
-						final Component newNodeViewInFocus = SwingUtilities.getAncestorOfClass(NodeView.class,
-						    focusedTable);
-						if (newNodeViewInFocus != null) {
-							final NodeView viewer = (NodeView) newNodeViewInFocus;
-							if (viewer != viewer.getMap().getSelected()) {
-								viewer.getMap().selectAsTheOnlyOneSelected(viewer, false);
-							}
-						}
-					}
-				}
-			});
-		}
-
-		/*
-		 * (non-Javadoc)
-		 * @see
-		 * java.awt.event.FocusListener#focusLost(java.awt.event.FocusEvent)
-		 */
-		public void focusLost(final FocusEvent event) {
-			if (event.isTemporary()) {
-				return;
-			}
-			final Component oppositeComponent = event.getOppositeComponent();
-			if (oppositeComponent == null) {
-				return;
-			}
-			final Component newTable;
-			if (oppositeComponent instanceof AttributeTable) {
-				newTable = oppositeComponent;
-			}
-			else {
-				newTable = SwingUtilities.getAncestorOfClass(AttributeTable.class, oppositeComponent);
-			}
-			if (focusedTable == null) {
-				return;
-			}
-			if (focusedTable != newTable) {
-				if (focusedTable.isEditing()) {
-					focusedTable.clearSelection();
-					focusedTable.getCellEditor().stopCellEditing();
-				}
-				if (!focusedTable.attributeView.isPopupShown()) {
-					final AttributeView attributeView = focusedTable.getAttributeView();
-					final String currentAttributeViewType = AttributeRegistry.getRegistry(
-					    attributeView.getNode().getMap()).getAttributeViewType();
-					if (attributeView.getViewType() != currentAttributeViewType) {
-						attributeView.stateChanged(null);
-					}
-				}
-				focusedTable = null;
-				return;
-			}
-		}
+	static {
+		globalFocusChangeListener = new AttributeSelectionChangeListener();
+		KeyboardFocusManager.getCurrentKeyboardFocusManager().addPropertyChangeListener("permanentFocusOwner", globalFocusChangeListener);
+		AttributeController.setAttributeSelection(globalFocusChangeListener);
 	}
 
 	static private MouseListener componentListener = new HeaderMouseListener();
 	static private ComboBoxModel defaultComboBoxModel = null;
 	static private AttributeTableCellRenderer dtcr = new AttributeTableCellRenderer();
 	private static final int EXTRA_HEIGHT = 4;
-	static private MyFocusListener focusListener = new MyFocusListener();
 	static private CursorUpdater cursorUpdater = new CursorUpdater();
 	private static final int MAX_HEIGTH = 300;
 	private static final int MAX_WIDTH = 300;
 	private static final long serialVersionUID = 1L;
-	private static final float TABLE_ROW_HEIGHT = 4;
+	private static final int CURSOR_WIDTH = 2;
+	public static AttributeTable getSelectedTable(){
+		return globalFocusChangeListener.selectedTable;
+	}
 
 	static ComboBoxModel getDefaultComboBoxModel() {
 		if (AttributeTable.defaultComboBoxModel == null) {
@@ -251,10 +208,14 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	private int highRowIndex = 0;
 	private static DefaultCellEditor dce;
 
+	private static final Set<String> editingActions = Stream.of((String)TransferHandler.getCopyAction().getValue(Action.NAME),
+		(String)TransferHandler.getPasteAction().getValue(Action.NAME), (String)TransferHandler.getCutAction().getValue(Action.NAME))
+			.collect(Collectors.toSet());
+
 	AttributeTable(final AttributeView attributeView) {
 		super();
 		this.attributeView = attributeView;
-		addFocusListener(AttributeTable.focusListener);
+		initializeTooltipManager(attributeView);
 		addMouseListener(AttributeTable.cursorUpdater);
 		addMouseMotionListener(AttributeTable.cursorUpdater);
 		if (attributeView.getMapView().getModeController().canEdit()) {
@@ -266,27 +227,58 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		setModel(attributeView.getCurrentAttributeTableModel());
 		setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
 		getTableHeader().setReorderingAllowed(false);
-		setRowSelectionAllowed(false);
+		setCellSelectionEnabled(true);
+		getSelectionModel().setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
 		putClientProperty("JTable.autoStartsEdit", Boolean.FALSE);
+		adaptActionMap(this);
 		setShowGrid(true);
 	}
-	
+
+	private static void adaptActionMap(AttributeTable table) {
+		InputMap ancestorInputMap = table.getInputMap(JTable.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
+		KeyStroke f2 = KeyStroke.getKeyStroke(KeyEvent.VK_F2, 0);
+		KeyStroke enter = KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0);
+		InputMap focusedComponentInputMap = table.getInputMap(JTable.WHEN_FOCUSED);
+		final Object editKey = ancestorInputMap.get(f2);
+		focusedComponentInputMap.put(enter, editKey);
+		final ActionMap actionMap = table.getActionMap();
+		if(defaultParentActionMap == null || defaultParentActionMap != actionMap.getParent()) {
+			defaultParentActionMap = actionMap.getParent();
+			newDefaultParentActionMap = new ActionMap() {
+
+				@Override
+				public Action get(Object key) {
+					if(editingActions.contains(key))
+						return null;
+					else
+						return super.get(key);
+				}
+
+			};
+			newDefaultParentActionMap.setParent(defaultParentActionMap);
+			EditCellAction action = new EditCellAction();
+			newDefaultParentActionMap.put(editKey, action);
+		}
+		actionMap.setParent(newDefaultParentActionMap);
+	}
+
+
+
+	private void initializeTooltipManager(AttributeView attributeView) {
+        ToolTipManager toolTipManager = ToolTipManager.sharedInstance();
+        toolTipManager.unregisterComponent(this);
+        NodeTooltipManager.getSharedInstance(attributeView.getMapView().getModeController()).registerComponent(this);
+
+	}
+
 	@Override
 	protected JTableHeader createDefaultTableHeader() {
 		return new TableHeader(columnModel);
 	}
 
 	private void changeSelectedRowHeight(final int rowIndex) {
-		if (highRowIndex != rowIndex) {
-			if (highRowIndex < getRowCount()) {
-				final int h = getRowHeight(highRowIndex);
-				setRowHeight(highRowIndex, h - AttributeTable.EXTRA_HEIGHT);
-			}
-			final int h = getRowHeight(rowIndex);
-			setRowHeight(rowIndex, h + AttributeTable.EXTRA_HEIGHT);
-			highRowIndex = rowIndex;
-			assert highRowIndex >= 0;
-		}
+		highRowIndex = rowIndex;
+		updateRowHeights();
 	}
 
 	@Override
@@ -303,6 +295,7 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		super.changeSelection(rowIndex, columnIndex, toggle, extend);
 	}
 
+	@Override
 	public void columnWidthChanged(final ColumnWidthChangeEvent event) {
 		final float zoom = getZoom();
 		final int col = event.getColumnNumber();
@@ -317,26 +310,26 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	/**
 	 * @return Returns the currentModel.
 	 */
-	public AttributeTableModelDecoratorAdapter getAttributeTableModel() {
-		return (AttributeTableModelDecoratorAdapter) getModel();
+	public AttributeTableModel getAttributeTableModel() {
+		return (AttributeTableModel) getModel();
 	}
 
 	public AttributeView getAttributeView() {
 		return attributeView;
 	}
-	
-	
+
+
 
 	@Override
     public boolean editCellAt(int row, int column, EventObject e) {
-		if(isEditing() && getCellEditor() instanceof DialogTableCellEditor){
+		if(isEditing() && getCellEditor() instanceof DialogTableCellEditor || ! isCellEditable(e)){
 			return false;
 		}
 		if(column == 1 && e instanceof MouseEvent){
 			final MouseEvent me = (MouseEvent) e;
 			final Object value = getValueAt(row, column);
-			if(value instanceof URI){
-				final URI uri = (URI) value;
+			URI uri =  toUri(value);
+			if(uri != null){
 				final Icon linkIcon = getLinkIcon(uri);
 				final int xmax = linkIcon != null ? linkIcon.getIconWidth() : 0;
 				final int x = me.getX() - getColumnModel().getColumn(0).getWidth();
@@ -353,7 +346,12 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 				if(isEditing() && cellEditor instanceof DialogTableCellEditor){
 					((JComponent)editorComp).paintImmediately(0, 0, editorComp.getWidth(), editorComp.getHeight());
 					((DialogTableCellEditor)cellEditor).startEditing();
-					return false;
+				}
+				else {
+					final Component editorComponent = getEditorComponent();
+					if (editorComponent instanceof JComboBox) {
+						startEditing(e, (JComboBox) editorComponent);
+					}
 				}
 				return true;
 			}
@@ -364,37 +362,71 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		}
     }
 
+	URI toUri(final Object value) {
+		return TextController.getController().toUri(value, attributeView.getNode(), null);
+	}
+
+	private void startEditing(EventObject e, final JComboBox comboBox) {
+		final ComboBoxEditor editor = comboBox.getEditor();
+		if (comboBox.isEditable()) {
+			editor.selectAll();
+			if(e instanceof KeyEvent) {
+				final KeyEvent keyEvent = (KeyEvent)e;
+				final char keyChar = keyEvent.getKeyChar();
+				if(keyChar != KeyEvent.CHAR_UNDEFINED) {
+					KeyEvent keyTypedEvent = new KeyEvent(editor.getEditorComponent(), KeyEvent.KEY_TYPED, keyEvent.getWhen(),
+							keyEvent.getModifiers(), KeyEvent.VK_UNDEFINED, keyChar, KeyEvent.KEY_LOCATION_UNKNOWN);
+					SwingUtilities.processKeyBindings(keyTypedEvent);
+				}
+			}
+		}
+		else {
+			comboBox.requestFocusInWindow();
+			SwingUtilities.invokeLater(new Runnable() {
+				@Override
+				public void run() {
+					comboBox.showPopup();
+				}
+			});
+		}
+	}
+
 	Icon getLinkIcon(final URI uri) {
-		NodeModel nodeModel = ((IAttributeTableModel)getModel()).getNode();
+		NodeModel nodeModel = ((AttributeTableModel)getModel()).getNode();
 	    final Icon linkIcon =  Controller.getCurrentModeController().getExtension(LinkController.class).getLinkIcon(uri, nodeModel);
 	    return linkIcon;
     }
-	
+
 	@SuppressWarnings("serial")
     private class DialogTableCellEditor extends AbstractCellEditor implements TableCellEditor{
-		
+
 		final private IEditControl editControl;
 		private Object value;
 		private EditNodeBase editBase;
 		public DialogTableCellEditor() {
 			super();
 			editControl = new IEditControl() {
+				@Override
 				public void split(String newText, int position) {
 				}
-				
+
+				@Override
 				public void ok(String newText) {
 					value = newText;
 					stopCellEditing();
 				}
-				
+
+				@Override
 				public void cancel() {
 					stopCellEditing();
 				}
 
+				@Override
 				public boolean canSplit() {
 	                return false;
                 }
 
+				@Override
 				public EditedComponent getEditType() {
 	                return EditedComponent.TEXT;
                 }
@@ -408,7 +440,8 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		public void setEditBase(EditNodeBase editBase) {
         	this.editBase = editBase;
         }
-		
+
+		@Override
 		public Object getCellEditorValue() {
 	        return value;
         }
@@ -421,12 +454,11 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 			editBase.show(frame);
 		}
 
+		@Override
 		public boolean isCellEditable(EventObject anEvent) {
-			if (anEvent instanceof MouseEvent) { 
-				return ((MouseEvent)anEvent).getClickCount() >= CLICK_COUNT_TO_START;
-			}
-			return true;
+			return AttributeTable.this.isCellEditable(anEvent);
 		}
+		@Override
 		public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row, int column) {
 	        return new AttributeTableCellRenderer().getTableCellRendererComponent(table, value, true, true, row, column);
         }
@@ -437,6 +469,12 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		return getCellEditor(row, col, (EventObject) getClientProperty("AttributeTable.EditEvent"));
 	}
 
+	private boolean isCellEditable(EventObject anEvent) {
+		if (anEvent instanceof MouseEvent) {
+			return ((MouseEvent)anEvent).getClickCount() >= CLICK_COUNT_TO_START;
+		}
+		return true;
+	}
 	@SuppressWarnings("serial")
     public TableCellEditor getCellEditor(final int row, final int col, EventObject e) {
 		if (dce != null) {
@@ -444,11 +482,8 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		}
 		if(col == 1){
 			final MTextController textController = (MTextController) TextController.getController();
-			if(e instanceof KeyEvent){
-				final KeyEvent kev = (KeyEvent) e;
-				textController.getEventQueue().setFirstEvent(kev);
-			}
-			final IAttributeTableModel model = (IAttributeTableModel) getModel();
+			textController.getEventQueue().setFirstEvent((e instanceof KeyEvent) ? ((KeyEvent) e) : null);
+			final AttributeTableModel model = (AttributeTableModel) getModel();
 			final String text = getValueForEdit(row, col);
 			final DialogTableCellEditor dialogTableCellEditor = new DialogTableCellEditor();
 			EditNodeBase base = textController.getEditNodeBase(model.getNode(), text, dialogTableCellEditor.getEditControl(), false);
@@ -470,13 +505,32 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 					else
 						super.actionPerformed(e);
 				}
-				
+
+			    private boolean layingOut = false;
+
+			    @Override
+				public void doLayout(){
+			        try{
+			            layingOut = true;
+			                super.doLayout();
+			        }finally{
+			            layingOut = false;
+			        }
+			    }
+
+			    @Override
+				public Dimension getSize(){
+			        Dimension dim = super.getSize();
+			        if(!layingOut)
+			            dim.width = Math.max(dim.width, getPreferredSize().width);
+			        return dim;
+			    }
+
 			};
-			comboBox.addFocusListener(AttributeTable.focusListener);
-			comboBox.getEditor().getEditorComponent().addFocusListener(AttributeTable.focusListener);
 			comboBox.setRenderer(new TypedListCellRenderer());
 			dce = new DefaultCellEditor(comboBox) {
-		        public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row, int col) {
+		        @Override
+				public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row, int col) {
 		            return super.getTableCellEditorComponent(table, ((AttributeTable)table).getValueForEdit(row, col), isSelected, row, col);
 		        }
 			};
@@ -502,7 +556,7 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 			validate();
 		}
 		final Dimension dimension = super.getPreferredSize();
-		NodeView nodeView = (NodeView) SwingUtilities.getAncestorOfClass(NodeView.class, this);
+		NodeView nodeView = getNodeViewAncestor();
 		if(nodeView != null){
 			final MapView map = nodeView.getMap();
 			final ModeController modeController = map.getModeController();
@@ -511,12 +565,16 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 			dimension.height = Math.min(map.getZoomed(AttributeTable.MAX_HEIGTH) - getTableHeaderHeight(), dimension.height);
 		}
 		else{
-			dimension.width = Math.min(MAX_WIDTH, dimension.width);
-			dimension.height = Math.min(MAX_HEIGTH, dimension.height);
+//			dimension.width = Math.min(MAX_WIDTH, dimension.width);
+//			dimension.height = Math.min(MAX_HEIGTH, dimension.height);
 		}
 		return dimension;
 	}
 
+	NodeView getNodeViewAncestor() {
+		return (NodeView) SwingUtilities.getAncestorOfClass(NodeView.class, this);
+	}
+
 	int getTableHeaderHeight() {
 		final JTableHeader tableHeader = getTableHeader();
 		return tableHeader != null ? tableHeader.getPreferredSize().height : 0;
@@ -611,29 +669,49 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	@Override
     public Component prepareRenderer(TableCellRenderer renderer, int row, int column) {
 	    Object value = getValueAt(row, column);
-        
+
             boolean isSelected = false;
             boolean hasFocus = false;
-        
+
             // Only indicate the selection and focused cell if not printing
             MapView map = (MapView) SwingUtilities.getAncestorOfClass(MapView.class, this);
             if (map == null || ! map.isPrinting()) {
                 isSelected = isCellSelected(row, column);
-        
+
                 boolean rowIsLead =
                     (selectionModel.getLeadSelectionIndex() == row);
                 boolean colIsLead =
                     (columnModel.getSelectionModel().getLeadSelectionIndex() == column);
-        
+
                 final Window windowAncestor = SwingUtilities.getWindowAncestor(this);
 				hasFocus = (rowIsLead && colIsLead) && windowAncestor != null && equals(windowAncestor.getMostRecentFocusOwner());
             }
-        
+
         return renderer.getTableCellRendererComponent(this, value,
                                                       isSelected, hasFocus,
                                                       row, column);
     }
-	
+
+
+	@Override
+	public JToolTip createToolTip() {
+		FreeplaneTooltip tip = new FreeplaneTooltip(this.getGraphicsConfiguration(), "text/html");
+
+		final URL url = attributeView.getNode().getMap().getURL();
+		if (url != null) {
+			tip.setBase(url);
+		}
+		else {
+			try {
+	            tip.setBase(new URL("file: "));
+            }
+            catch (MalformedURLException e) {
+            }
+		}
+		tip.setComponent(this);
+		return tip;
+	}
+
 	@Override
 	protected boolean processKeyBinding(final KeyStroke ks, final KeyEvent e, final int condition, final boolean pressed) {
 		if (ks.getKeyCode() == KeyEvent.VK_TAB && e.getModifiers() == 0 && pressed && getSelectedColumn() == 1
@@ -648,49 +726,36 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 			}
 			else
 				return super.processKeyBinding(ks, e, condition, pressed);
-				
+
 		}
-		boolean retValue = super.processKeyBinding(ks, e, condition, pressed);
-		if (!retValue && condition == JComponent.WHEN_FOCUSED && isFocusOwner() && ks.getKeyCode() != KeyEvent.VK_TAB
+		if(super.processKeyBinding(ks, e, condition, pressed))
+			return true;
+		if (condition == JComponent.WHEN_FOCUSED)
+			return editCell(ks, e);
+		return false;
+	}
+
+	private boolean editCell(final KeyStroke ks, final KeyEvent e) {
+		if (isFocusOwner() && ks.getKeyCode() != KeyEvent.VK_TAB
 		        && e != null && e.getID() == KeyEvent.KEY_PRESSED && !e.isActionKey()
 		        && e.getKeyChar() != KeyEvent.CHAR_UNDEFINED
 		        && 0 == (e.getModifiers() & (InputEvent.CTRL_MASK | InputEvent.ALT_MASK))) {
 			final int leadRow = getSelectionModel().getLeadSelectionIndex();
 			final int leadColumn = getColumnModel().getSelectionModel().getLeadSelectionIndex();
-			if (leadRow != -1 && leadColumn != -1 && !isEditing()) {
-				if (!editCellAt(leadRow, leadColumn, e)) {
+			if (leadRow == -1 || leadColumn == -1  || isEditing() || !editCellAt(leadRow, leadColumn, e)) {
 					return false;
-				}
 			}
-			final Component editorComponent = getEditorComponent();
-			if (editorComponent instanceof JComboBox) {
-				final JComboBox comboBox = (JComboBox) editorComponent;
-				if (comboBox.isEditable()) {
-					final ComboBoxEditor editor = comboBox.getEditor();
-					editor.selectAll();
-					KeyEvent keyEv;
-					keyEv = new KeyEvent(editor.getEditorComponent(), KeyEvent.KEY_TYPED, e.getWhen(),
-					    e.getModifiers(), KeyEvent.VK_UNDEFINED, e.getKeyChar(), KeyEvent.KEY_LOCATION_UNKNOWN);
-					retValue = SwingUtilities.processKeyBindings(keyEv);
-				}
-				else {
-					editorComponent.requestFocusInWindow();
-					retValue = true;
-				}
-			}
-		}
-		if (ks.getKeyCode() == KeyEvent.VK_SPACE) {
 			return true;
 		}
-		return retValue;
+		return false;
 	}
 
 	@Override
 	public void removeEditor() {
 		final Component editorComponent = getEditorComponent();
 		final Component focusOwner = KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusOwner();
-		boolean requestFocus = editorComponent != null && focusOwner != null && 
-		(focusOwner == editorComponent || SwingUtilities.isDescendingFrom(focusOwner, editorComponent)); 
+		boolean requestFocus = editorComponent != null && focusOwner != null &&
+		(focusOwner == editorComponent || SwingUtilities.isDescendingFrom(focusOwner, editorComponent));
 		getAttributeTableModel().editingCanceled();
 		final boolean focusCycleRoot = isFocusCycleRoot();
 		setFocusCycleRoot(true);
@@ -726,18 +791,19 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	 */
 	public void setOptimalColumnWidths() {
 		Component comp = null;
-		int cellWidth = 0;
-		int maxCellWidth = 2 * (int) (Math.ceil(getFont().getSize2D() / UITools.FONT_SCALE_FACTOR +  AttributeTable.TABLE_ROW_HEIGHT));
+		int maxCellWidth = 2 * (int) (Math.ceil(getFont().getSize2D() / UITools.FONT_SCALE_FACTOR +  EXTRA_HEIGHT));
 		int rowCount = getRowCount();
+		boolean isInsideNodeView = getNodeViewAncestor() != null;
 		if(rowCount > 0) {
 			for (int col = 0; col < 2; col++) {
 				for (int row = 0; row < rowCount; row++) {
 					comp = AttributeTable.dtcr.getTableCellRendererComponent(this, getValueAt(row, col), false, false, row,
 							col);
-					cellWidth = comp.getPreferredSize().width;
+					final Dimension preferredSize = comp.getPreferredSize();
+					int cellWidth = preferredSize.width + preferredSize.height +  EXTRA_HEIGHT + CURSOR_WIDTH + 1;
 					maxCellWidth = Math.max(cellWidth, maxCellWidth);
 				}
-				getAttributeTableModel().setColumnWidth(col, LengthUnits.pixelsInPt(maxCellWidth + 1));
+				getAttributeTableModel().setColumnWidth(col, LengthUnits.pixelsInPt(maxCellWidth));
 			}
 		}
 	}
@@ -781,9 +847,6 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 					}
 			}
 		getParent().getParent().invalidate();
-		final NodeModel node = attributeView.getNode();
-		MapController mapController = attributeView.getMapView().getModeController().getMapController();
-		mapController.nodeChanged(node, NodeAttributeTableModel.class, null, null);
 	}
 
 	void updateAttributeTable() {
@@ -810,14 +873,22 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	}
 
 	private Color gridColor = null;
+	private static ActionMap defaultParentActionMap;
+	private static ActionMap newDefaultParentActionMap;
 	public void setGridAndBorderColor(Color gridColor) {
 		this.gridColor = gridColor;
 		if(gridColor != null) {
 			if(! gridColor.equals(getGridColor())) {
-				AttributeViewScrollPane scrollPane = (AttributeViewScrollPane) SwingUtilities.getAncestorOfClass(AttributeViewScrollPane.class, this);
 				final Border border = BorderFactory.createLineBorder(gridColor);
-				scrollPane.setBorder(border);
-				scrollPane.setViewportBorder(border);
+				final JComponent parent = (JComponent) getParent();
+				if(parent instanceof JViewport) {
+					JScrollPane scrollPane = (JScrollPane) parent.getParent();
+					scrollPane.setBorder(border);
+					scrollPane.setViewportBorder(border);
+				}
+				else {
+					parent.setBorder(border);
+				}
 				super.setGridColor(gridColor);
 			}
 		}
@@ -835,7 +906,7 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		final NodeView nodeView = attributeView.getNodeView();
 		final MapView mapView = nodeView.getMap();
 		final ModeController modeController = mapView.getModeController();
-		final NodeStyleController style = (NodeStyleController) modeController.getExtension(NodeStyleController.class);
+		final NodeStyleController style = modeController.getExtension(NodeStyleController.class);
         final MapStyleModel model = MapStyleModel.getExtension(mapView.getModel());
         final NodeModel attributeStyleNode = model.getStyleNodeSafe(MapStyleModel.ATTRIBUTE_STYLE);
         final Font font = style.getFont(attributeStyleNode);
@@ -857,6 +928,7 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	private void updateRowHeights() {
 		if(! isDisplayable()){
 			addHierarchyListener(new HierarchyListener() {
+				@Override
 				public void hierarchyChanged(HierarchyEvent e) {
 					if(isDisplayable()){
 						updateRowHeights();
@@ -870,20 +942,12 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		if (rowCount == 0) {
 			return;
 		}
-		final int constHeight = getTableHeaderHeight() + AttributeTable.EXTRA_HEIGHT;
-		final float zoom = getZoom();
 		final float fontSize = (float) getFont().getMaxCharBounds(((Graphics2D)getGraphics()).getFontRenderContext()).getHeight();
-		final float tableRowHeight = fontSize + zoom * AttributeTable.TABLE_ROW_HEIGHT;
-		int newHeight = (int) ((tableRowHeight * rowCount + (zoom - 1) * constHeight) / rowCount);
-		if (newHeight < 1) {
-			newHeight = 1;
-		}
-		final int highRowsNumber = (int) ((tableRowHeight - newHeight) * rowCount);
-		for (int i = 0; i < highRowsNumber; i++) {
-			setRowHeight(i, 1 + newHeight + (i == highRowIndex ? AttributeTable.EXTRA_HEIGHT : 0));
-		}
-		for (int i = highRowsNumber; i < rowCount; i++) {
-			setRowHeight(i, newHeight + (i == highRowIndex ? AttributeTable.EXTRA_HEIGHT : 0));
+		final float zoom = getZoom();
+		final int extraHeight = (int)(zoom * EXTRA_HEIGHT + 0.7f);
+		int rowHeight = Math.max(1, (int)fontSize + extraHeight);
+		for (int i = 0; i <  rowCount; i++) {
+			setRowHeight(i, rowHeight + (i == highRowIndex ? AttributeTable.EXTRA_HEIGHT : 0));
 		}
 	}
 
@@ -902,7 +966,9 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 					final Object value = editor.getCellEditorValue();
 					if (value != null) {
 						final String pattern = extractPatternIfAvailable(getValueAt(editingRow, editingColumn));
-						final Object newValue = enforceFormattedObjectForIdentityPattern(value, pattern);
+				        final MTextController textController = (MTextController) TextController.getController();
+				        final Object object = textController.guessObject(value, pattern);
+						final Object newValue = enforceFormattedObjectForIdentityPattern(object, pattern);
 						setValueAt(newValue, editingRow, editingColumn);
 					}
 					removeEditor();
@@ -921,9 +987,7 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
     // unfortunately we have to handle IDENTITY_PATTERN explicitely since (only) attributes
     // have no place for the format except for the value itself - so we need a FormattedObject here
     private Object enforceFormattedObjectForIdentityPattern(Object value, final String pattern) {
-        final MTextController textController = (MTextController) TextController.getController();
-        return PatternFormat.IDENTITY_PATTERN.equals(pattern) ? new FormattedObject(value, pattern) : textController
-            .guessObjectOrURI(value, pattern);
+        return PatternFormat.IDENTITY_PATTERN.equals(pattern) ? new FormattedObject(value, pattern) : value;
     }
 
 	@Override
@@ -937,8 +1001,8 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	    super.valueChanged(e);
 	    setSelectedCellTypeInfo();
     }
-	
-	
+
+
 
 	@Override
     public void columnSelectionChanged(ListSelectionEvent e) {
@@ -946,7 +1010,7 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	    setSelectedCellTypeInfo();
     }
 
-	private void setSelectedCellTypeInfo() {
+	void setSelectedCellTypeInfo() {
 		final int r = getSelectedRow();
 		final int c = getSelectedColumn();
 		if(r >= 0 && c >= 0){
@@ -966,6 +1030,6 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		super.paintComponent(g);
 	}
 
-	
+
 
 }
