@@ -21,9 +21,11 @@ package org.freeplane.plugin.script;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.PrintStream;
-import java.net.URL;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
 import java.util.List;
 
 import javax.script.Bindings;
@@ -90,12 +92,6 @@ public class GenericScript implements IScript {
 
     private Throwable errorsInScript;
 
-    private IFreeplaneScriptErrorHandler errorHandler;
-
-    private PrintStream outStream;
-
-    private ScriptContext scriptContext;
-
 	private ScriptEngine engine;
 
     private boolean compilationEnabled = true;
@@ -110,9 +106,6 @@ public class GenericScript implements IScript {
 		this.engine = null;
         compiledScript = null;
         errorsInScript = null;
-        errorHandler = ScriptResources.IGNORING_SCRIPT_ERROR_HANDLER;
-        outStream = System.out;
-        scriptContext = null;
 		scriptClassLoader = ScriptClassLoader.createClassLoader();
     }
 
@@ -121,13 +114,15 @@ public class GenericScript implements IScript {
         compileTimeStrategy = new CompileTimeStrategy(null);
     }
 
-    public GenericScript(String script, String scriptEngineName, ScriptingPermissions permissions) {
+    public GenericScript(String script, String type, ScriptingPermissions permissions) {
 		init(script, permissions);
 		ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
 		try {
 			Thread.currentThread().setContextClassLoader(scriptClassLoader);
 			ScriptEngineManager scriptEngineManager = createScriptEngineManager(scriptClassLoader);
-			engine = checkNotNull(scriptEngineManager.getEngineByName(scriptEngineName), "name", scriptEngineName);
+			final ScriptEngine engineByExtension = scriptEngineManager.getEngineByExtension(type);
+			final ScriptEngine engine = engineByExtension != null ? engineByExtension :  scriptEngineManager.getEngineByName(type);
+			this.engine = checkNotNull(engine, type);
 		}
 		finally {
 			Thread.currentThread().setContextClassLoader(contextClassLoader);
@@ -141,7 +136,7 @@ public class GenericScript implements IScript {
 			Thread.currentThread().setContextClassLoader(scriptClassLoader);
 			ScriptEngineManager scriptEngineManager = createScriptEngineManager(scriptClassLoader);
 			final String extension = FilenameUtils.getExtension(scriptFile.getName());
-			engine = checkNotNull(scriptEngineManager.getEngineByExtension(extension), "extension", extension);
+			engine = checkNotNull(scriptEngineManager.getEngineByExtension(extension), extension);
 		}
 		finally {
 			Thread.currentThread().setContextClassLoader(contextClassLoader);
@@ -159,31 +154,9 @@ public class GenericScript implements IScript {
         }
     }
 
-    @Override
-    public IScript setErrorHandler(IFreeplaneScriptErrorHandler pErrorHandler) {
-        this.errorHandler = pErrorHandler;
-        return this;
-    }
 
     @Override
-    public IScript setOutStream(PrintStream outStream) {
-        this.outStream = outStream;
-        return this;
-    }
-
-    @Override
-    public IScript setScriptContext(ScriptContext scriptContext) {
-        this.scriptContext = scriptContext;
-        return this;
-    }
-
-    @Override
-    public Object getScript() {
-        return scriptSource;
-    }
-
-    @Override
-    public Object execute(final NodeModel node) {
+    public Object execute(final NodeModel node, PrintStream outStream, IFreeplaneScriptErrorHandler errorHandler, ScriptContext scriptContext) {
         try {
             if (errorsInScript != null && compileTimeStrategy.canUseOldCompiledScript()) {
                 throw new ExecuteScriptException(errorsInScript.getMessage(), errorsInScript);
@@ -191,10 +164,17 @@ public class GenericScript implements IScript {
             final PrintStream oldOut = System.out;
 			ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
             try {
-				final ScriptingSecurityManager scriptingSecurityManager = createScriptingSecurityManager();
-				scriptClassLoader.setSecurityManager(scriptingSecurityManager);
+				AccessController.doPrivileged(new PrivilegedAction<Void>() {
+
+					@Override
+					public Void run() {
+						final ScriptingSecurityManager scriptingSecurityManager = createScriptingSecurityManager(outStream);
+						scriptClassLoader.setSecurityManager(scriptingSecurityManager);
+						return null;
+					}
+				});
 				Thread.currentThread().setContextClassLoader(scriptClassLoader);
-                final SimpleScriptContext context = createScriptContext(node);
+                final SimpleScriptContext context = createScriptContext(node, scriptContext, outStream);
                 if (compilationEnabled && engine instanceof Compilable) {
                     compileAndCache((Compilable) engine);
                     System.setOut(outStream);
@@ -208,7 +188,7 @@ public class GenericScript implements IScript {
 				Thread.currentThread().setContextClassLoader(contextClassLoader);
             }
         } catch (final ScriptException e) {
-            handleScriptRuntimeException(e);
+            handleScriptRuntimeException(e, outStream, errorHandler);
             // :fixme: This throw is only reached, if
             // handleScriptRuntimeException
             // does not raise an exception. Should it be here at all?
@@ -223,7 +203,7 @@ public class GenericScript implements IScript {
     }
 
 
-    private ScriptingSecurityManager createScriptingSecurityManager() {
+    private ScriptingSecurityManager createScriptingSecurityManager(PrintStream outStream) {
         return new ScriptSecurity(scriptSource, specificPermissions, outStream)
                 .getScriptingSecurityManager();
     }
@@ -233,16 +213,16 @@ public class GenericScript implements IScript {
                 ScriptResources.SCRIPT_COMPILATION_DISABLED_EXTENSIONS);
     }
 
-    private SimpleScriptContext createScriptContext(final NodeModel node) {
+    private SimpleScriptContext createScriptContext(final NodeModel node, ScriptContext scriptContext, OutputStream outStream) {
         final SimpleScriptContext context = new SimpleScriptContext();
         final OutputStreamWriter outWriter = new OutputStreamWriter(outStream);
         context.setWriter(outWriter);
 		context.setErrorWriter(outWriter);
-        context.setBindings(createBinding(node), javax.script.ScriptContext.ENGINE_SCOPE);
+        context.setBindings(createBinding(node, scriptContext), javax.script.ScriptContext.ENGINE_SCOPE);
         return context;
     }
 
-    private Bindings createBinding(final NodeModel node) {
+    private Bindings createBinding(final NodeModel node, ScriptContext scriptContext) {
         final Bindings binding = engine.createBindings();
         binding.put("c", ProxyFactory.createController(scriptContext));
         binding.put("node", ProxyFactory.createNode(node, scriptContext));
@@ -279,14 +259,14 @@ public class GenericScript implements IScript {
         }
     }
 
-    private static ScriptEngine checkNotNull(final ScriptEngine motor, String what, String detail) {
+    private static ScriptEngine checkNotNull(final ScriptEngine motor, String detail) {
         if (motor == null) {
-            throw new RuntimeException("can't load script engine by " + what + ": " + detail);
+            throw new RuntimeException("can't load script engine " + detail);
         }
         return motor;
     }
 
-    private void handleScriptRuntimeException(final ScriptException e) {
+    private void handleScriptRuntimeException(final ScriptException e, PrintStream outStream, IFreeplaneScriptErrorHandler errorHandler) {
         outStream.print("message: " + e.getMessage());
         int lineNumber = e.getLineNumber();
         outStream.print("Line number: " + lineNumber);
@@ -298,7 +278,7 @@ public class GenericScript implements IScript {
     }
 
     @Override
-    public boolean permissionsEquals(ScriptingPermissions permissions) {
+    public boolean hasPermissions(ScriptingPermissions permissions) {
         if (this.specificPermissions == null) {
             return this.specificPermissions == permissions;
         } else {
