@@ -32,11 +32,10 @@ import javax.swing.UIManager;
 
 import org.apache.batik.dom.GenericDOMImplementation;
 import org.apache.batik.svggen.SVGGeneratorContext;
-import org.apache.batik.svggen.SVGGraphics2D;
 import org.apache.batik.svggen.SVGGeneratorContext.GraphicContextDefaults;
+import org.apache.batik.svggen.SVGGraphics2D;
 import org.apache.batik.util.SVGConstants;
 import org.freeplane.features.export.mindmapmode.IExportEngine;
-import org.freeplane.features.mode.Controller;
 import org.freeplane.view.swing.map.MapView;
 import org.w3c.dom.DOMImplementation;
 import org.w3c.dom.Document;
@@ -45,10 +44,6 @@ import org.w3c.dom.Document;
  * @author foltin
  */
 abstract class ExportVectorGraphic implements IExportEngine {
-	/**
-	 * 
-	 */
-	private static final long serialVersionUID = 1L;
 
 	/**
 	 */
